@@ -2,11 +2,12 @@
 /**
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Björn Schießle <bjoern@schiessle.org>
- * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Georg Ehrke <georg@owncloud.com>
+ * @author Joas Schilling <coding@schilljs.com>
  * @author Stefan Weil <sw@weilnetz.de>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -27,9 +28,9 @@ namespace OCA\DAV\CardDAV;
 
 use OC\Cache\CappedMemoryCache;
 use OCA\DAV\Connector\Sabre\Principal;
-use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCA\DAV\DAV\Sharing\Backend;
 use OCA\DAV\DAV\Sharing\IShareable;
+use OCP\DB\QueryBuilder\IQueryBuilder;
 use OCP\IDBConnection;
 use PDO;
 use Sabre\CardDAV\Backend\BackendInterface;
@@ -63,12 +64,14 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 	private $idCache;
 
 	/** @var array properties to index */
-	public static $indexProperties = array(
+	public static $indexProperties = [
 			'BDAY', 'UID', 'N', 'FN', 'TITLE', 'ROLE', 'NOTE', 'NICKNAME',
-			'ORG', 'CATEGORIES', 'EMAIL', 'TEL', 'IMPP', 'ADR', 'URL', 'GEO', 'CLOUD');
+			'ORG', 'CATEGORIES', 'EMAIL', 'TEL', 'IMPP', 'ADR', 'URL', 'GEO', 'CLOUD'];
 
 	/** @var EventDispatcherInterface */
 	private $dispatcher;
+	/** @var bool */
+	private $legacyMode;
 
 	/**
 	 * CardDavBackend constructor.
@@ -79,11 +82,13 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 	 */
 	public function __construct(IDBConnection $db,
 								Principal $principalBackend,
-								EventDispatcherInterface $dispatcher = null) {
+								EventDispatcherInterface $dispatcher = null,
+								$legacyMode = false) {
 		$this->db = $db;
 		$this->principalBackend = $principalBackend;
 		$this->dispatcher = $dispatcher;
 		$this->sharingBackend = new Backend($this->db, $principalBackend, 'addressbook');
+		$this->legacyMode = $legacyMode;
 		$this->idCache = new CappedMemoryCache();
 	}
 
@@ -104,8 +109,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 	 * @param string $principalUri
 	 * @return array
 	 */
-	function getAddressBooksForUser($principalUri) {
-		$principalUriOriginal = $principalUri;
+	function getUsersOwnAddressBooks($principalUri) {
 		$principalUri = $this->convertPrincipal($principalUri, true);
 		$query = $this->db->getQueryBuilder();
 		$query->select(['id', 'uri', 'displayname', 'principaluri', 'description', 'synctoken'])
@@ -115,21 +119,44 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 		$addressBooks = [];
 
 		$result = $query->execute();
-		while($row = $result->fetch()) {
+		while ($row = $result->fetch()) {
 			$addressBooks[$row['id']] = [
-				'id'  => $row['id'],
+				'id' => $row['id'],
 				'uri' => $row['uri'],
-				'principaluri' => $this->convertPrincipal($row['principaluri'], false),
+				'principaluri' => $this->convertPrincipal($row['principaluri']),
 				'{DAV:}displayname' => $row['displayname'],
 				'{' . Plugin::NS_CARDDAV . '}addressbook-description' => $row['description'],
 				'{http://calendarserver.org/ns/}getctag' => $row['synctoken'],
-				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+				'{http://sabredav.org/ns}sync-token' => $row['synctoken'] ?: '0',
 			];
 		}
 		$result->closeCursor();
+		return array_values($addressBooks);
+	}
+
+	/**
+	 * Returns the list of address books for a specific user, including shared by other users.
+	 *
+	 * Every addressbook should have the following properties:
+	 *   id - an arbitrary unique id
+	 *   uri - the 'basename' part of the url
+	 *   principaluri - Same as the passed parameter
+	 *
+	 * Any additional clark-notation property may be passed besides this. Some
+	 * common ones are :
+	 *   {DAV:}displayname
+	 *   {urn:ietf:params:xml:ns:carddav}addressbook-description
+	 *   {http://calendarserver.org/ns/}getctag
+	 *
+	 * @param string $principalUri
+	 * @return array
+	 * @throws \Sabre\DAV\Exception
+	 */
+	function getAddressBooksForUser($principalUri) {
+		$addressBooks = $this->getUsersOwnAddressBooks($principalUri);
 
 		// query for shared calendars
-		$principals = $this->principalBackend->getGroupMembership($principalUriOriginal, true);
+		$principals = $this->principalBackend->getGroupMembership($principalUri, true);
 		$principals[]= $principalUri;
 
 		$query = $this->db->getQueryBuilder();
@@ -154,7 +181,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 					'{DAV:}displayname' => $displayName,
 					'{' . Plugin::NS_CARDDAV . '}addressbook-description' => $row['description'],
 					'{http://calendarserver.org/ns/}getctag' => $row['synctoken'],
-					'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+					'{http://sabredav.org/ns}sync-token' => $row['synctoken']?:'0',
 					'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}owner-principal' => $row['principaluri'],
 					'{' . \OCA\DAV\DAV\Sharing\Plugin::NS_OWNCLOUD . '}read-only' => (int)$row['access'] === Backend::ACCESS_READ,
 				];
@@ -188,7 +215,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 			'{DAV:}displayname' => $row['displayname'],
 			'{' . Plugin::NS_CARDDAV . '}addressbook-description' => $row['description'],
 			'{http://calendarserver.org/ns/}getctag' => $row['synctoken'],
-			'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+			'{http://sabredav.org/ns}sync-token' => $row['synctoken']?:'0',
 		];
 	}
 
@@ -218,7 +245,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 				'{DAV:}displayname' => $row['displayname'],
 				'{' . Plugin::NS_CARDDAV . '}addressbook-description' => $row['description'],
 				'{http://calendarserver.org/ns/}getctag' => $row['synctoken'],
-				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?$row['synctoken']:'0',
+				'{http://sabredav.org/ns}sync-token' => $row['synctoken']?:'0',
 			];
 	}
 
@@ -267,7 +294,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 			$query->where($query->expr()->eq('id', $query->createNamedParameter($addressBookId)))
 			->execute();
 
-			$this->addChange($addressBookId, "", 2);
+			$this->addChange($addressBookId, '', 2);
 
 			return true;
 
@@ -281,6 +308,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 	 * @param string $url Just the 'basename' of the url.
 	 * @param array $properties
 	 * @return int
+	 * @throws \BadMethodCallException
 	 * @throws BadRequest
 	 */
 	function createAddressBook($principalUri, $url, array $properties) {
@@ -309,7 +337,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 
 		// Fallback to make sure the displayname is set. Some clients may refuse
 		// to work with addressbooks not having a displayname.
-		if(is_null($values['displayname'])) {
+		if(null === $values['displayname']) {
 			$values['displayname'] = $url;
 		}
 
@@ -441,24 +469,33 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 	 * @return array
 	 */
 	function getMultipleCards($addressBookId, array $uris) {
-		$query = $this->db->getQueryBuilder();
-		$query->select(['id', 'uri', 'lastmodified', 'etag', 'size', 'carddata'])
-			->from('cards')
-			->where($query->expr()->eq('addressbookid', $query->createNamedParameter($addressBookId)))
-			->andWhere($query->expr()->in('uri', $query->createParameter('uri')))
-			->setParameter('uri', $uris, IQueryBuilder::PARAM_STR_ARRAY);
+		$chunkSize = 998;
+		if (count($uris) <= $chunkSize) {
+			$query = $this->db->getQueryBuilder();
+			$query->select(['id', 'uri', 'lastmodified', 'etag', 'size', 'carddata'])
+				->from('cards')
+				->where($query->expr()->eq('addressbookid', $query->createNamedParameter($addressBookId)))
+				->andWhere($query->expr()->in('uri', $query->createParameter('uri')))
+				->setParameter('uri', $uris, IQueryBuilder::PARAM_STR_ARRAY);
 
-		$cards = [];
+			$cards = [];
 
-		$result = $query->execute();
-		while($row = $result->fetch()) {
-			$row['etag'] = '"' . $row['etag'] . '"';
-			$row['carddata'] = $this->readBlob($row['carddata']);
-			$cards[] = $row;
+			$result = $query->execute();
+			while ($row = $result->fetch()) {
+				$row['etag'] = '"' . $row['etag'] . '"';
+				$row['carddata'] = $this->readBlob($row['carddata']);
+				$cards[] = $row;
+			}
+			$result->closeCursor();
+
+			return $cards;
 		}
-		$result->closeCursor();
+		$chunks = array_chunk($uris, $chunkSize);
+		$results = array_map(function ($chunk) use ($addressBookId) {
+			return $this->getMultipleCards($addressBookId, $chunk);
+		}, $chunks);
 
-		return $cards;
+		return array_merge(...$results);
 	}
 
 	/**
@@ -485,6 +522,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 	 * @param string $cardUri
 	 * @param string $cardData
 	 * @return string
+	 * @throws \BadMethodCallException
 	 */
 	function createCard($addressBookId, $cardUri, $cardData) {
 		$etag = md5($cardData);
@@ -507,7 +545,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 		$this->addChange($addressBookId, $cardUri, 1);
 		$this->updateProperties($addressBookId, $cardUri, $cardData);
 
-		if (!is_null($this->dispatcher)) {
+		if (null !== $this->dispatcher) {
 			$this->dispatcher->dispatch('\OCA\DAV\CardDAV\CardDavBackend::createCard',
 				new GenericEvent(null, [
 					'addressBookId' => $addressBookId,
@@ -559,7 +597,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 		$this->addChange($addressBookId, $cardUri, 2);
 		$this->updateProperties($addressBookId, $cardUri, $cardData);
 
-		if (!is_null($this->dispatcher)) {
+		if (null !== $this->dispatcher) {
 			$this->dispatcher->dispatch('\OCA\DAV\CardDAV\CardDavBackend::updateCard',
 				new GenericEvent(null, [
 					'addressBookId' => $addressBookId,
@@ -591,7 +629,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 
 		$this->addChange($addressBookId, $cardUri, 3);
 
-		if (!is_null($this->dispatcher)) {
+		if (null !== $this->dispatcher) {
 			$this->dispatcher->dispatch('\OCA\DAV\CardDAV\CardDavBackend::deleteCard',
 				new GenericEvent(null, [
 					'addressBookId' => $addressBookId,
@@ -668,9 +706,11 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 		// Current synctoken
 		$stmt = $this->db->prepare('SELECT `synctoken` FROM `*PREFIX*addressbooks` WHERE `id` = ?');
 		$stmt->execute([ $addressBookId ]);
-		$currentToken = $stmt->fetchColumn(0);
+		$currentToken = $stmt->fetchColumn();
 
-		if (is_null($currentToken)) return null;
+		if (null === $currentToken) {
+			return null;
+		}
 
 		$result = [
 			'syncToken' => $currentToken,
@@ -681,13 +721,10 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 
 		if ($syncToken) {
 
-			$query = "SELECT `uri`, `operation` FROM `*PREFIX*addressbookchanges` WHERE `synctoken` >= ? AND `synctoken` < ? AND `addressbookid` = ? ORDER BY `synctoken`";
-			if ($limit>0) {
-				$query .= " `LIMIT` " . (int)$limit;
-			}
+			$query = 'SELECT `uri`, `operation` FROM `*PREFIX*addressbookchanges` WHERE `synctoken` >= ? AND `synctoken` < ? AND `addressbookid` = ? ORDER BY `synctoken`';
 
 			// Fetching all changes
-			$stmt = $this->db->prepare($query);
+			$stmt = $this->db->prepare($query, $limit ?: null, $limit ? 0 : null);
 			$stmt->execute([$syncToken, $currentToken, $addressBookId]);
 
 			$changes = [];
@@ -717,7 +754,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 			}
 		} else {
 			// No synctoken supplied, this is the initial sync.
-			$query = "SELECT `uri` FROM `*PREFIX*cards` WHERE `addressbookid` = ?";
+			$query = 'SELECT `uri` FROM `*PREFIX*cards` WHERE `addressbookid` = ?';
 			$stmt = $this->db->prepare($query);
 			$stmt->execute([$addressBookId]);
 
@@ -784,7 +821,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 			$query2->orWhere(
 				$query2->expr()->andX(
 					$query2->expr()->eq('cp.name', $query->createNamedParameter($property)),
-					$query2->expr()->ilike('cp.value', $query->createNamedParameter('%' . $this->db->escapeLikeParameter($pattern) . '%'))
+					$query2->expr()->iLike('cp.value', $query->createNamedParameter('%' . $this->db->escapeLikeParameter($pattern) . '%'))
 				)
 			);
 		}
@@ -831,6 +868,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 	 *
 	 * @param int $id
 	 * @return string
+	 * @throws \InvalidArgumentException
 	 */
 	public function getCardUri($id) {
 		$query = $this->db->getQueryBuilder();
@@ -914,7 +952,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 				]
 			);
 
-		foreach ($vCard->children as $property) {
+		foreach ($vCard->children() as $property) {
 			if(!in_array($property->name, self::$indexProperties)) {
 				continue;
 			}
@@ -962,6 +1000,7 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 	 * @param int $addressBookId
 	 * @param string $uri
 	 * @return int
+	 * @throws \InvalidArgumentException
 	 */
 	protected function getCardId($addressBookId, $uri) {
 		// Try to find cardId from own cache to avoid issue with db cluster
@@ -995,10 +1034,11 @@ class CardDavBackend implements BackendInterface, SyncSupport {
 		return $this->sharingBackend->applyShareAcl($addressBookId, $acl);
 	}
 
-	private function convertPrincipal($principalUri, $toV2) {
+	private function convertPrincipal($principalUri, $toV2 = null) {
 		if ($this->principalBackend->getPrincipalPrefix() === 'principals') {
 			list(, $name) = URLUtil::splitPath($principalUri);
-			if ($toV2 === true) {
+			$toV2 = $toV2 === null ? !$this->legacyMode : $toV2;
+			if ($toV2) {
 				return "principals/users/$name";
 			}
 			return "principals/$name";
