@@ -1,8 +1,9 @@
 <?php
 /**
- * @author Arthur Schiwon <blizzz@owncloud.com>
+ * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Jesús Macias <jmacias@solidgear.es>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
+ * @author Juan Pablo Villafañez <jvillafanez@solidgear.es>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Philipp Kapfer <philipp.kapfer@gmx.at>
@@ -11,7 +12,7 @@
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -43,11 +44,10 @@ use Icewind\Streams\CallbackWrapper;
 use Icewind\Streams\IteratorDirectory;
 use OC\Cache\CappedMemoryCache;
 use OC\Files\Filesystem;
-use OC\Files\Storage\Common;
 use OCP\Files\StorageNotAvailableException;
 use OCP\Util;
 
-class SMB extends Common {
+class SMB extends \OCP\Files\Storage\StorageAdapter {
 	/**
 	 * @var \Icewind\SMB\Server
 	 */
@@ -297,7 +297,12 @@ class SMB extends Common {
 	 */
 	public function stat($path) {
 		$this->log('enter: '.__FUNCTION__."($path)");
-		$result = $this->formatInfo($this->getFileInfo($path));
+		try {
+			$result = $this->formatInfo($this->getFileInfo($path));
+		} catch (NotFoundException $e) {
+			$this->swallow(__FUNCTION__, $e);
+			$result = false;
+		}
 		return $this->leave(__FUNCTION__, $result);
 	}
 
@@ -658,14 +663,14 @@ class SMB extends Common {
 	 * @param int $level
 	 * @param string $from
 	 */
-	private function log($message, $level = Util::DEBUG, $from = 'wnd') {
-		if (\OC::$server->getConfig()->getSystemValue('wnd.logging.enable', false) === true) {
+	private function log($message, $level = Util::DEBUG, $from = 'smb') {
+		if (\OC::$server->getConfig()->getSystemValue('smb.logging.enable', false) === true) {
 			Util::writeLog($from, $message, $level);
 		}
 	}
 
 	/**
-	 * if wnd.logging.enable is set to true in the config will log a leave line
+	 * if smb.logging.enable is set to true in the config will log a leave line
 	 * with the given function, the return value or the exception
 	 *
 	 * @param $function
@@ -673,31 +678,31 @@ class SMB extends Common {
 	 * @return mixed
 	 */
 	private function leave($function, $result) {
-		if (\OC::$server->getConfig()->getSystemValue('wnd.logging.enable', false) === false) {
+		if (\OC::$server->getConfig()->getSystemValue('smb.logging.enable', false) === false) {
 			//don't bother building log strings
 			return $result;
 		} else if ($result === true) {
-			Util::writeLog('wnd', "leave: $function, return true", Util::DEBUG);
+			Util::writeLog('smb', "leave: $function, return true", Util::DEBUG);
 		} else if ($result === false) {
-			Util::writeLog('wnd', "leave: $function, return false", Util::DEBUG);
+			Util::writeLog('smb', "leave: $function, return false", Util::DEBUG);
 		} else if (is_string($result)) {
-			Util::writeLog('wnd', "leave: $function, return '$result'", Util::DEBUG);
+			Util::writeLog('smb', "leave: $function, return '$result'", Util::DEBUG);
 		} else if (is_resource($result)) {
-			Util::writeLog('wnd', "leave: $function, return resource", Util::DEBUG);
+			Util::writeLog('smb', "leave: $function, return resource", Util::DEBUG);
 		} else if ($result instanceof \Exception) {
-			Util::writeLog('wnd', "leave: $function, throw ".get_class($result)
+			Util::writeLog('smb', "leave: $function, throw ".get_class($result)
 				.' - code: '.$result->getCode()
 				.' message: '.$result->getMessage()
 				.' trace: '.$result->getTraceAsString(), Util::DEBUG);
 		} else {
-			Util::writeLog('wnd', "leave: $function, return ".json_encode($result, true), Util::DEBUG);
+			Util::writeLog('smb', "leave: $function, return ".json_encode($result, true), Util::DEBUG);
 		}
 		return $result;
 	}
 
 	private function swallow($function, \Exception $exception) {
-		if (\OC::$server->getConfig()->getSystemValue('wnd.logging.enable', false) === true) {
-			Util::writeLog('wnd', "$function swallowing ".get_class($exception)
+		if (\OC::$server->getConfig()->getSystemValue('smb.logging.enable', false) === true) {
+			Util::writeLog('smb', "$function swallowing ".get_class($exception)
 				.' - code: '.$exception->getCode()
 				.' message: '.$exception->getMessage()
 				.' trace: '.$exception->getTraceAsString(), Util::DEBUG);
