@@ -1,9 +1,10 @@
 <?php
 /**
- * @author Björn Schießle <bjoern@schiessle.org>
+ * @author Michael Jobst <mjobst+github@tecratech.de>
  * @author Roeland Jago Douma <rullzer@owncloud.com>
+ * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -21,20 +22,23 @@
  */
 namespace OCA\Files_Sharing\API;
 
+use OCP\Files\IRootFolder;
 use OCP\Files\NotFoundException;
+use OCP\IConfig;
 use OCP\IGroupManager;
 use OCP\IL10N;
-use OCP\IUserManager;
 use OCP\IRequest;
 use OCP\IURLGenerator;
 use OCP\IUser;
-use OCP\Files\IRootFolder;
-use OCP\Lock\LockedException;
-use OCP\Share\IShare;
-use OCP\Share\IManager;
-use OCP\Share\Exceptions\ShareNotFound;
-use OCP\Share\Exceptions\GenericShareException;
+use OCP\IUserManager;
 use OCP\Lock\ILockingProvider;
+use OCP\Lock\LockedException;
+use OCP\Share\Exceptions\GenericShareException;
+use OCP\Share\Exceptions\ShareNotFound;
+use OCP\Share\IManager;
+use OCP\Share\IShare;
+use Symfony\Component\EventDispatcher\EventDispatcher;
+use Symfony\Component\EventDispatcher\GenericEvent;
 
 /**
  * Class Share20OCS
@@ -59,6 +63,16 @@ class Share20OCS {
 	private $currentUser;
 	/** @var IL10N */
 	private $l;
+	/** @var IConfig */
+	private $config;
+
+	/**
+	 * @var string
+	 */
+	private $additionalInfoField;
+
+	/** @var \Symfony\Component\EventDispatcher\EventDispatcherInterface  */
+	private $eventDispatcher;
 
 	/**
 	 * Share20OCS constructor.
@@ -70,6 +84,9 @@ class Share20OCS {
 	 * @param IRootFolder $rootFolder
 	 * @param IURLGenerator $urlGenerator
 	 * @param IUser $currentUser
+	 * @param IL10N $l10n
+	 * @param IConfig $config
+	 * @param EventDispatcher $eventDispatcher
 	 */
 	public function __construct(
 			IManager $shareManager,
@@ -79,7 +96,9 @@ class Share20OCS {
 			IRootFolder $rootFolder,
 			IURLGenerator $urlGenerator,
 			IUser $currentUser,
-			IL10N $l10n
+			IL10N $l10n,
+			IConfig $config,
+			EventDispatcher $eventDispatcher
 	) {
 		$this->shareManager = $shareManager;
 		$this->userManager = $userManager;
@@ -89,6 +108,24 @@ class Share20OCS {
 		$this->urlGenerator = $urlGenerator;
 		$this->currentUser = $currentUser;
 		$this->l = $l10n;
+		$this->config = $config;
+		$this->additionalInfoField = $this->config->getAppValue('core', 'user_additional_info_field', '');
+		$this->eventDispatcher = $eventDispatcher;
+	}
+
+	/**
+	 * Returns the additional info to display behind the display name as configured.
+	 *
+	 * @param IUser $user user for which to retrieve the additional info
+	 * @return string|null additional info or null if none to be displayed
+	 */
+	private function getAdditionalUserInfo(IUser $user) {
+		if ($this->additionalInfoField === 'email') {
+			return $user->getEMailAddress();
+		} else if ($this->additionalInfoField === 'id') {
+			return $user->getUID();
+		}
+		return null;
 	}
 
 	/**
@@ -108,7 +145,7 @@ class Share20OCS {
 			'uid_owner' => $share->getSharedBy(),
 			'displayname_owner' => $sharedBy !== null ? $sharedBy->getDisplayName() : $share->getSharedBy(),
 			'permissions' => $share->getPermissions(),
-			'stime' => $share->getShareTime()->getTimestamp(),
+			'stime' => $share->getShareTime() ? $share->getShareTime()->getTimestamp() : null,
 			'parent' => null,
 			'expiration' => null,
 			'token' => null,
@@ -143,16 +180,23 @@ class Share20OCS {
 			$sharedWith = $this->userManager->get($share->getSharedWith());
 			$result['share_with'] = $share->getSharedWith();
 			$result['share_with_displayname'] = $sharedWith !== null ? $sharedWith->getDisplayName() : $share->getSharedWith();
+			if ($sharedWith !== null) {
+				$result['share_with_additional_info'] = $this->getAdditionalUserInfo($sharedWith);
+			}
 		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_GROUP) {
+			$group = $this->groupManager->get($share->getSharedWith());
 			$result['share_with'] = $share->getSharedWith();
-			$result['share_with_displayname'] = $share->getSharedWith();
+			$result['share_with_displayname'] = $group !== null ? $group->getDisplayName() : $share->getSharedWith();
 		} else if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
 
 			$result['share_with'] = $share->getPassword();
 			$result['share_with_displayname'] = $share->getPassword();
+			$result['name'] = $share->getName();
 
 			$result['token'] = $share->getToken();
-			$result['url'] = $this->urlGenerator->linkToRouteAbsolute('files_sharing.sharecontroller.showShare', ['token' => $share->getToken()]);
+			if ($share->getToken() !== null) {
+				$result['url'] = $this->urlGenerator->linkToRouteAbsolute('files_sharing.sharecontroller.showShare', ['token' => $share->getToken()]);
+			}
 
 			$expiration = $share->getExpirationDate();
 			if ($expiration !== null) {
@@ -174,87 +218,98 @@ class Share20OCS {
 	 * Get a specific share by id
 	 *
 	 * @param string $id
-	 * @return \OC_OCS_Result
+	 * @return \OC\OCS\Result
 	 */
 	public function getShare($id) {
 		if (!$this->shareManager->shareApiEnabled()) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Share API is disabled'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Share API is disabled'));
 		}
 
 		try {
 			$share = $this->getShareById($id);
 		} catch (ShareNotFound $e) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
 		}
 
 		if ($this->canAccessShare($share)) {
 			try {
 				$share = $this->formatShare($share);
-				return new \OC_OCS_Result([$share]);
+				return new \OC\OCS\Result([$share]);
 			} catch (NotFoundException $e) {
 				//Fall trough
 			}
 		}
 
-		return new \OC_OCS_Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
+		return new \OC\OCS\Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
 	}
 
 	/**
 	 * Delete a share
 	 *
 	 * @param string $id
-	 * @return \OC_OCS_Result
+	 * @return \OC\OCS\Result
 	 */
 	public function deleteShare($id) {
 		if (!$this->shareManager->shareApiEnabled()) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Share API is disabled'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Share API is disabled'));
 		}
 
 		try {
 			$share = $this->getShareById($id);
 		} catch (ShareNotFound $e) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
 		}
 
 		try {
 			$share->getNode()->lock(ILockingProvider::LOCK_SHARED);
 		} catch (LockedException $e) {
-			return new \OC_OCS_Result(null, 404, 'could not delete share');
+			return new \OC\OCS\Result(null, 404, 'could not delete share');
 		}
 
 		if (!$this->canAccessShare($share)) {
 			$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-			return new \OC_OCS_Result(null, 404, $this->l->t('Could not delete share'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Could not delete share'));
 		}
 
 		$this->shareManager->deleteShare($share);
 
 		$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
 
-		return new \OC_OCS_Result();
+		return new \OC\OCS\Result();
 	}
 
 	/**
-	 * @return \OC_OCS_Result
+	 * @return \OC\OCS\Result
 	 */
 	public function createShare() {
+		$event = new GenericEvent(null);
+		$beforeEvent = new GenericEvent(null);
 		$share = $this->shareManager->newShare();
 
 		if (!$this->shareManager->shareApiEnabled()) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Share API is disabled'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Share API is disabled'));
 		}
 
+		$name = $this->request->getParam('name', null);
+
 		// Verify path
 		$path = $this->request->getParam('path', null);
 		if ($path === null) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Please specify a file or folder path'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Please specify a file or folder path'));
 		}
 
 		$userFolder = $this->rootFolder->getUserFolder($this->currentUser->getUID());
+		$beforeEvent->setArgument('userFolder', $userFolder);
+		$beforeEvent->setArgument('run', true);
+
+		if ($beforeEvent->getArgument('run') === false) {
+			return new \OC\OCS\Result(null, 403, $this->l->t('No permission to create share'));
+		}
+
 		try {
 			$path = $userFolder->get($path);
 		} catch (NotFoundException $e) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Wrong path, file/folder doesn\'t exist'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Wrong path, file/folder doesn\'t exist'));
 		}
 
 		$share->setNode($path);
@@ -262,24 +317,38 @@ class Share20OCS {
 		try {
 			$share->getNode()->lock(ILockingProvider::LOCK_SHARED);
 		} catch (LockedException $e) {
-			return new \OC_OCS_Result(null, 404, 'Could not create share');
+			return new \OC\OCS\Result(null, 404, 'Could not create share');
 		}
 
+		$shareType = (int)$this->request->getParam('shareType', '-1');
+
 		// Parse permissions (if available)
 		$permissions = $this->request->getParam('permissions', null);
 		if ($permissions === null) {
-			$permissions = \OCP\Constants::PERMISSION_ALL;
+			if ($shareType !== \OCP\Share::SHARE_TYPE_LINK) {
+				$permissions = $this->config->getAppValue('core', 'shareapi_default_permissions', \OCP\Constants::PERMISSION_ALL);
+				$permissions |= \OCP\Constants::PERMISSION_READ;
+			} else {
+				$permissions = \OCP\Constants::PERMISSION_ALL;
+			}
 		} else {
 			$permissions = (int)$permissions;
 		}
 
 		if ($permissions < 0 || $permissions > \OCP\Constants::PERMISSION_ALL) {
 			$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-			return new \OC_OCS_Result(null, 404, 'invalid permissions');
+			return new \OC\OCS\Result(null, 404, 'invalid permissions');
 		}
 
-		// Shares always require read permissions
-		$permissions |= \OCP\Constants::PERMISSION_READ;
+		if ($permissions === 0) {
+			return new \OC\OCS\Result(null, 400, $this->l->t('Cannot remove all permissions'));
+		}
+
+		// link shares can have create-only without read (anonymous upload)
+		if ($shareType !== \OCP\Share::SHARE_TYPE_LINK && $permissions !== \OCP\Constants::PERMISSION_CREATE) {
+			// Shares always require read permissions
+			$permissions |= \OCP\Constants::PERMISSION_READ;
+		}
 
 		if ($path instanceof \OCP\Files\File) {
 			// Single file shares should never have delete or create permissions
@@ -297,26 +366,25 @@ class Share20OCS {
 		}
 
 		$shareWith = $this->request->getParam('shareWith', null);
-		$shareType = (int)$this->request->getParam('shareType', '-1');
 
 		if ($shareType === \OCP\Share::SHARE_TYPE_USER) {
 			// Valid user is required to share
 			if ($shareWith === null || !$this->userManager->userExists($shareWith)) {
 				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result(null, 404, $this->l->t('Please specify a valid user'));
+				return new \OC\OCS\Result(null, 404, $this->l->t('Please specify a valid user'));
 			}
 			$share->setSharedWith($shareWith);
 			$share->setPermissions($permissions);
 		} else if ($shareType === \OCP\Share::SHARE_TYPE_GROUP) {
 			if (!$this->shareManager->allowGroupSharing()) {
 				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result(null, 404, $this->l->t('Group sharing is disabled by the administrator'));
+				return new \OC\OCS\Result(null, 404, $this->l->t('Group sharing is disabled by the administrator'));
 			}
 
 			// Valid group is required to share
 			if ($shareWith === null || !$this->groupManager->groupExists($shareWith)) {
 				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result(null, 404, $this->l->t('Please specify a valid group'));
+				return new \OC\OCS\Result(null, 404, $this->l->t('Please specify a valid group'));
 			}
 			$share->setSharedWith($shareWith);
 			$share->setPermissions($permissions);
@@ -324,43 +392,48 @@ class Share20OCS {
 			//Can we even share links?
 			if (!$this->shareManager->shareApiAllowLinks()) {
 				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result(null, 404, $this->l->t('Public link sharing is disabled by the administrator'));
-			}
-
-			/*
-			 * For now we only allow 1 link share.
-			 * Return the existing link share if this is a duplicate
-			 */
-			$existingShares = $this->shareManager->getSharesBy($this->currentUser->getUID(), \OCP\Share::SHARE_TYPE_LINK, $path, false, 1, 0);
-			if (!empty($existingShares)) {
-				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result($this->formatShare($existingShares[0]));
+				return new \OC\OCS\Result(null, 404, $this->l->t('Public link sharing is disabled by the administrator'));
 			}
 
+			// legacy way, expecting that this won't be used together with "create-only" shares
 			$publicUpload = $this->request->getParam('publicUpload', null);
-			if ($publicUpload === 'true') {
+			// a few permission checks
+			if ($publicUpload === 'true' || $permissions === \OCP\Constants::PERMISSION_CREATE) {
 				// Check if public upload is allowed
 				if (!$this->shareManager->shareApiLinkAllowPublicUpload()) {
 					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-					return new \OC_OCS_Result(null, 403, $this->l->t('Public upload disabled by the administrator'));
+					return new \OC\OCS\Result(null, 403, $this->l->t('Public upload disabled by the administrator'));
 				}
 
 				// Public upload can only be set for folders
 				if ($path instanceof \OCP\Files\File) {
 					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-					return new \OC_OCS_Result(null, 404, $this->l->t('Public upload is only possible for publicly shared folders'));
+					return new \OC\OCS\Result(null, 404, $this->l->t('Public upload is only possible for publicly shared folders'));
 				}
+			}
 
+			// convert to permissions
+			if ($publicUpload === 'true') {
 				$share->setPermissions(
 					\OCP\Constants::PERMISSION_READ |
 					\OCP\Constants::PERMISSION_CREATE |
 					\OCP\Constants::PERMISSION_UPDATE |
 					\OCP\Constants::PERMISSION_DELETE
 				);
+			} else if ($permissions === \OCP\Constants::PERMISSION_CREATE ||
+					$permissions === (\OCP\Constants::PERMISSION_READ | \OCP\Constants::PERMISSION_CREATE | \OCP\Constants::PERMISSION_UPDATE | \OCP\Constants::PERMISSION_DELETE)) {
+				$share->setPermissions($permissions);
 			} else {
+				// because when "publicUpload" is passed usually no permissions are set,
+				// which defaults to ALL. But in the case of link shares we default to READ...
 				$share->setPermissions(\OCP\Constants::PERMISSION_READ);
 			}
 
+			// set name only if passed as parameter, empty string is allowed
+			if ($name !== null) {
+				$share->setName($name);
+			}
+
 			// Set password
 			$password = $this->request->getParam('password', '');
 
@@ -377,21 +450,21 @@ class Share20OCS {
 					$share->setExpirationDate($expireDate);
 				} catch (\Exception $e) {
 					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-					return new \OC_OCS_Result(null, 404, $this->l->t('Invalid date, date format must be YYYY-MM-DD'));
+					return new \OC\OCS\Result(null, 404, $this->l->t('Invalid date, date format must be YYYY-MM-DD'));
 				}
 			}
 
 		} else if ($shareType === \OCP\Share::SHARE_TYPE_REMOTE) {
 			if (!$this->shareManager->outgoingServer2ServerSharesAllowed()) {
 				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result(null, 403, $this->l->t('Sharing %s failed because the back end does not allow shares from type %s', [$path->getPath(), $shareType]));
+				return new \OC\OCS\Result(null, 403, $this->l->t('Sharing %s failed because the back end does not allow shares from type %s', [$path->getPath(), $shareType]));
 			}
 
 			$share->setSharedWith($shareWith);
 			$share->setPermissions($permissions);
 		} else {
 			$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-			return new \OC_OCS_Result(null, 400, $this->l->t('Unknown share type'));
+			return new \OC\OCS\Result(null, 400, $this->l->t('Unknown share type'));
 		}
 
 		$share->setShareType($shareType);
@@ -402,24 +475,27 @@ class Share20OCS {
 		} catch (GenericShareException $e) {
 			$code = $e->getCode() === 0 ? 403 : $e->getCode();
 			$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-			return new \OC_OCS_Result(null, $code, $e->getHint());
+			return new \OC\OCS\Result(null, $code, $e->getHint());
 		}catch (\Exception $e) {
 			$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-			return new \OC_OCS_Result(null, 403, $e->getMessage());
+			return new \OC\OCS\Result(null, 403, $e->getMessage());
 		}
 
-		$output = $this->formatShare($share);
+
 
 		$share->getNode()->unlock(\OCP\Lock\ILockingProvider::LOCK_SHARED);
 
-		return new \OC_OCS_Result($output);
+
+		$formattedShareAfterCreate = $this->formatShare($share);
+		return new \OC\OCS\Result($formattedShareAfterCreate);
 	}
 
 	/**
 	 * @param \OCP\Files\File|\OCP\Files\Folder $node
-	 * @return \OC_OCS_Result
+	 * @param boolean $includeTags
+	 * @return \OC\OCS\Result
 	 */
-	private function getSharedWithMe($node = null) {
+	private function getSharedWithMe($node = null, $includeTags) {
 		$userShares = $this->shareManager->getSharedWith($this->currentUser->getUID(), \OCP\Share::SHARE_TYPE_USER, $node, -1, 0);
 		$groupShares = $this->shareManager->getSharedWith($this->currentUser->getUID(), \OCP\Share::SHARE_TYPE_GROUP, $node, -1, 0);
 
@@ -440,16 +516,20 @@ class Share20OCS {
 			}
 		}
 
-		return new \OC_OCS_Result($formatted);
+		if ($includeTags) {
+			$formatted = \OCA\Files\Helper::populateTags($formatted, 'file_source');
+		}
+
+		return new \OC\OCS\Result($formatted);
 	}
 
 	/**
 	 * @param \OCP\Files\Folder $folder
-	 * @return \OC_OCS_Result
+	 * @return \OC\OCS\Result
 	 */
 	private function getSharesInDir($folder) {
 		if (!($folder instanceof \OCP\Files\Folder)) {
-			return new \OC_OCS_Result(null, 400, $this->l->t('Not a directory'));
+			return new \OC\OCS\Result(null, 400, $this->l->t('Not a directory'));
 		}
 
 		$nodes = $folder->getDirectoryListing();
@@ -473,7 +553,7 @@ class Share20OCS {
 			}
 		}
 
-		return new \OC_OCS_Result($formatted);
+		return new \OC\OCS\Result($formatted);
 	}
 
 	/**
@@ -485,11 +565,11 @@ class Share20OCS {
 	 * - Get shares for a specific path (?path=...)
 	 * - Get all shares in a folder (?subfiles=true&path=..)
 	 *
-	 * @return \OC_OCS_Result
+	 * @return \OC\OCS\Result
 	 */
 	public function getShares() {
 		if (!$this->shareManager->shareApiEnabled()) {
-			return new \OC_OCS_Result();
+			return new \OC\OCS\Result();
 		}
 
 		$sharedWithMe = $this->request->getParam('shared_with_me', null);
@@ -497,20 +577,22 @@ class Share20OCS {
 		$subfiles = $this->request->getParam('subfiles');
 		$path = $this->request->getParam('path', null);
 
+		$includeTags = $this->request->getParam('include_tags', false);
+
 		if ($path !== null) {
 			$userFolder = $this->rootFolder->getUserFolder($this->currentUser->getUID());
 			try {
 				$path = $userFolder->get($path);
 				$path->lock(ILockingProvider::LOCK_SHARED);
 			} catch (\OCP\Files\NotFoundException $e) {
-				return new \OC_OCS_Result(null, 404, $this->l->t('Wrong path, file/folder doesn\'t exist'));
+				return new \OC\OCS\Result(null, 404, $this->l->t('Wrong path, file/folder doesn\'t exist'));
 			} catch (LockedException $e) {
-				return new \OC_OCS_Result(null, 404, $this->l->t('Could not lock path'));
+				return new \OC\OCS\Result(null, 404, $this->l->t('Could not lock path'));
 			}
 		}
 
 		if ($sharedWithMe === 'true') {
-			$result = $this->getSharedWithMe($path);
+			$result = $this->getSharedWithMe($path, $includeTags);
 			if ($path !== null) {
 				$path->unlock(ILockingProvider::LOCK_SHARED);
 			}
@@ -551,47 +633,52 @@ class Share20OCS {
 			}
 		}
 
+		if ($includeTags) {
+			$formatted = \OCA\Files\Helper::populateTags($formatted, 'file_source');
+		}
+
 		if ($path !== null) {
 			$path->unlock(ILockingProvider::LOCK_SHARED);
 		}
 
-		return new \OC_OCS_Result($formatted);
+		return new \OC\OCS\Result($formatted);
 	}
 
 	/**
 	 * @param int $id
-	 * @return \OC_OCS_Result
+	 * @return \OC\OCS\Result
 	 */
 	public function updateShare($id) {
 		if (!$this->shareManager->shareApiEnabled()) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Share API is disabled'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Share API is disabled'));
 		}
 
 		try {
 			$share = $this->getShareById($id);
 		} catch (ShareNotFound $e) {
-			return new \OC_OCS_Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
 		}
 
 		$share->getNode()->lock(\OCP\Lock\ILockingProvider::LOCK_SHARED);
 
 		if (!$this->canAccessShare($share)) {
 			$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-			return new \OC_OCS_Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
+			return new \OC\OCS\Result(null, 404, $this->l->t('Wrong share ID, share doesn\'t exist'));
 		}
 
 		$permissions = $this->request->getParam('permissions', null);
 		$password = $this->request->getParam('password', null);
 		$publicUpload = $this->request->getParam('publicUpload', null);
 		$expireDate = $this->request->getParam('expireDate', null);
+		$name = $this->request->getParam('name', null);
 
 		/*
 		 * expirationdate, password and publicUpload only make sense for link shares
 		 */
 		if ($share->getShareType() === \OCP\Share::SHARE_TYPE_LINK) {
-			if ($permissions === null && $password === null && $publicUpload === null && $expireDate === null) {
+			if ($permissions === null && $password === null && $publicUpload === null && $expireDate === null && $name === null) {
 				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result(null, 400, 'Wrong or no update parameter given');
+				return new \OC\OCS\Result(null, 400, 'Wrong or no update parameter given');
 			}
 
 			$newPermissions = null;
@@ -607,13 +694,14 @@ class Share20OCS {
 
 			if ($newPermissions !== null &&
 				$newPermissions !== \OCP\Constants::PERMISSION_READ &&
+				$newPermissions !== \OCP\Constants::PERMISSION_CREATE &&
 				// legacy
 				$newPermissions !== (\OCP\Constants::PERMISSION_READ | \OCP\Constants::PERMISSION_CREATE | \OCP\Constants::PERMISSION_UPDATE) &&
 				// correct
 				$newPermissions !== (\OCP\Constants::PERMISSION_READ | \OCP\Constants::PERMISSION_CREATE | \OCP\Constants::PERMISSION_UPDATE | \OCP\Constants::PERMISSION_DELETE)
 			) {
 				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result(null, 400, $this->l->t('Can\'t change permissions for public share links'));
+				return new \OC\OCS\Result(null, 400, $this->l->t('Can\'t change permissions for public share links'));
 			}
 
 			if (
@@ -624,18 +712,50 @@ class Share20OCS {
 			) {
 				if (!$this->shareManager->shareApiLinkAllowPublicUpload()) {
 					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-					return new \OC_OCS_Result(null, 403, $this->l->t('Public upload disabled by the administrator'));
+					return new \OC\OCS\Result(null, 403, $this->l->t('Public upload disabled by the administrator'));
 				}
 
 				if (!($share->getNode() instanceof \OCP\Files\Folder)) {
 					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-					return new \OC_OCS_Result(null, 400, $this->l->t('Public upload is only possible for publicly shared folders'));
+					return new \OC\OCS\Result(null, 400, $this->l->t('Public upload is only possible for publicly shared folders'));
 				}
 
 				// normalize to correct public upload permissions
 				$newPermissions = \OCP\Constants::PERMISSION_READ | \OCP\Constants::PERMISSION_CREATE | \OCP\Constants::PERMISSION_UPDATE | \OCP\Constants::PERMISSION_DELETE;
 			}
 
+			// create-only (upload-only)
+			if (
+				$newPermissions === \OCP\Constants::PERMISSION_CREATE
+			) {
+				if (!$this->shareManager->shareApiLinkAllowPublicUpload()) {
+					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
+					return new \OC\OCS\Result(null, 403, $this->l->t('Public upload disabled by the administrator'));
+				}
+
+				if (!($share->getNode() instanceof \OCP\Files\Folder)) {
+					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
+					return new \OC\OCS\Result(null, 400, $this->l->t('Public upload is only possible for publicly shared folders'));
+				}
+			}
+
+			// set name only if passed as parameter, empty string is allowed
+			if ($name !== null) {
+				$oldname = $share->getName();
+				$share->setName($name);
+
+				//Trigger update event for name change only if name differ
+				if ($name !== $oldname) {
+					$shareAfterNameUpdate = new GenericEvent(null);
+					$shareAfterNameUpdate->setArguments([
+						'sharenameupdated' => true,
+						'oldname' => $oldname,
+						'shareobject' => $share,
+					]);
+					$this->eventDispatcher->dispatch('share.afterupdate', $shareAfterNameUpdate);
+				}
+			}
+
 			if ($newPermissions !== null) {
 				$share->setPermissions($newPermissions);
 				$permissions = $newPermissions;
@@ -648,7 +768,7 @@ class Share20OCS {
 					$expireDate = $this->parseDate($expireDate);
 				} catch (\Exception $e) {
 					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-					return new \OC_OCS_Result(null, 400, $e->getMessage());
+					return new \OC\OCS\Result(null, 400, $e->getMessage());
 				}
 				$share->setExpirationDate($expireDate);
 			}
@@ -663,7 +783,7 @@ class Share20OCS {
 			// For other shares only permissions is valid.
 			if ($permissions === null) {
 				$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-				return new \OC_OCS_Result(null, 400, $this->l->t('Wrong or no update parameter given'));
+				return new \OC\OCS\Result(null, 400, $this->l->t('Wrong or no update parameter given'));
 			} else {
 				$permissions = (int)$permissions;
 				$share->setPermissions($permissions);
@@ -683,22 +803,25 @@ class Share20OCS {
 
 				if ($share->getPermissions() & ~$maxPermissions) {
 					$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-					return new \OC_OCS_Result(null, 404, $this->l->t('Cannot increase permissions'));
+					return new \OC\OCS\Result(null, 404, $this->l->t('Cannot increase permissions'));
 				}
 			}
 		}
 
+		if ($share->getPermissions() === 0) {
+			return new \OC\OCS\Result(null, 400, $this->l->t('Cannot remove all permissions'));
+		}
 
 		try {
 			$share = $this->shareManager->updateShare($share);
 		} catch (\Exception $e) {
 			$share->getNode()->unlock(ILockingProvider::LOCK_SHARED);
-			return new \OC_OCS_Result(null, 400, $e->getMessage());
+			return new \OC\OCS\Result(null, 400, $e->getMessage());
 		}
 
 		$share->getNode()->unlock(\OCP\Lock\ILockingProvider::LOCK_SHARED);
 
-		return new \OC_OCS_Result($this->formatShare($share));
+		return new \OC\OCS\Result($this->formatShare($share));
 	}
 
 	/**
