@@ -3,29 +3,28 @@
 <a id="closeWizard" class="close">
 	<img class="svg" src="<?php print_unescaped(OCP\Util::imagePath('core', 'actions/close.svg')); ?>">
 </a>
-<h1><?php p($l->t('Welcome to %s', array($theme->getTitle()))); ?></h1>
-<?php if ($_['edition'] === ''): ?>
-<p><?php p($l->t('Your personal web services. All your files, contacts, calendar and more, in one place.'));?></p>
+<h1><?php p($l->t('A safe home for all your data')); ?></h1>
+<?php if ($_['edition'] === \OC_Util::EDITION_COMMUNITY): ?>
+<p><?php p($l->t('Access & share your files, calendars, contacts, mail & more from any device, on your terms'));?></p>
 <?php else: ?>
 <p><?php p($theme->getSlogan()); ?></p>
 <?php endif; ?>
 
-
 <h2><?php p($l->t('Get the apps to sync your files'));?></h2>
 <a target="_blank" href="<?php p($_['clients']['desktop']); ?>">
-	<img src="<?php print_unescaped(OCP\Util::imagePath('core', 'desktopapp.png')); ?>"
+	<img src="<?php print_unescaped(OCP\Util::imagePath('core', 'desktopapp.svg')); ?>"
 		alt="<?php p($l->t('Desktop client'));?>" />
 </a>
 <a target="_blank" href="<?php p($_['clients']['android']); ?>">
 	<img src="<?php print_unescaped(OCP\Util::imagePath('core', 'googleplay.png')); ?>"
-		alt="<?php p($l->t('Android app'));?>" />
+		alt="<?php p($l->t('Android app'));?>" style="height:60px"/>
 </a>
 <a target="_blank" href="<?php p($_['clients']['ios']); ?>">
-	<img src="<?php print_unescaped(OCP\Util::imagePath('core', 'appstore.png')); ?>"
-		alt="<?php p($l->t('iOS app'));?>" />
+	<img src="<?php print_unescaped(OCP\Util::imagePath('core', 'appstore.svg')); ?>"
+		alt="<?php p($l->t('iOS app'));?>" style="height:60px"/>
 </a>
 
-<?php if ($_['edition'] === ''): ?>
+<?php if ($_['edition'] === \OC_Util::EDITION_COMMUNITY): ?>
 <h2><?php p($l->t('Connect your desktop apps to %s', array($theme->getName()))); ?></h2>
 <a target="_blank" class="button" href="<?php p(link_to_docs('user-sync-calendars')) ?>">
 	<img class="appsmall appsmall-calendar svg" alt=""
@@ -54,13 +53,13 @@
 <?php print_unescaped($l->t('There’s more information in the <a target="_blank" href="%s">documentation</a> and on our <a target="_blank" href="http://owncloud.org">website</a>.', array(link_to_docs('user_manual')))); ?><br>
 <?php print_unescaped($l->t('If you like ownCloud,
 	<a href="mailto:?subject=ownCloud
-		&body=ownCloud is a great open software to sync and share your files. 
+		&body=ownCloud is a great open software to sync and share your files.
 		You can freely get it from http://owncloud.org">
 		recommend it to your friends</a>
 	and <a href="http://owncloud.org/promote"
 		target="_blank">spread the word</a>!')); ?>
 <?php else: ?>
-<?php p(date('Y')) ?> <a href="<?php p($theme->getBaseUrl()); ?>" target="_blank"><?php p($theme->getEntity()); ?></a>
+© <?php p(date('Y')) ?> <a href="<?php p($theme->getBaseUrl()); ?>" target="_blank"><?php p($theme->getEntity()); ?></a>
 <?php endif; ?>
 </p>
 
