@@ -6,18 +6,19 @@
  * @author Craig Morrissey <craig@owncloud.com>
  * @author dampfklon <me@dampfklon.de>
  * @author Felix Böhm <felixboehm@gmx.de>
- * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Joas Schilling <coding@schilljs.com>
  * @author Leonardo Diez <leio10@users.noreply.github.com>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Michael Gapczynski <GapczynskiM@gmail.com>
  * @author Morris Jobke <hey@morrisjobke.de>
+ * @author neumann <node512@gmail.com>
  * @author Ramiro Aparicio <rapariciog@gmail.com>
  * @author Robin Appelman <icewind@owncloud.com>
  * @author Roeland Jago Douma <rullzer@owncloud.com>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Thomas Tanghus <thomas@tanghus.net>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -34,6 +35,7 @@
  *
  */
 
+use OC\Share\Filters\MailNotificationFilter;
 use OCP\IUser;
 
 OC_JSON::checkLoggedIn();
@@ -41,6 +43,61 @@ OCP\JSON::callCheck();
 
 $defaults = new \OCP\Defaults();
 
+/**
+ * @return mixed
+ */
+function getGroups($search = '', $limit = null, $offset = null) {
+	$groups = \OC::$server->getGroupManager()->search($search, $limit, $offset);
+	$groupIds = [];
+	foreach ($groups as $group) {
+		$groupIds[] = $group->getGID();
+	}
+	return $groupIds;
+}
+
+/**
+ * @param $gids
+ * @param $limit
+ * @param $offset
+ * @return mixed
+ */
+function displayNamesInGroups($gids, $search = '', $limit = -1, $offset = 0) {
+	$displayNames = [];
+	foreach ($gids as $gid) {
+		// TODO Need to apply limits to groups as total
+		$diff = array_diff(
+			\OC::$server->getGroupManager()->displayNamesInGroup($gid, $search, $limit, $offset),
+			$displayNames
+		);
+		if ($diff) {
+			// A fix for LDAP users. array_merge loses keys...
+			$displayNames = $diff + $displayNames;
+		}
+	}
+	return $displayNames;
+}
+
+/**
+ * @param $gid
+ * @param string $search
+ * @param int $limit
+ * @param int $offset
+ * @return array
+ */
+function usersInGroup($gid, $search = '', $limit = -1, $offset = 0) {
+	$group = \OC::$server->getGroupManager()->get($gid);
+	if ($group) {
+		$users = $group->searchUsers($search, $limit, $offset);
+		$userIds = [];
+		foreach ($users as $user) {
+			$userIds[] = $user->getUID();
+		}
+		return $userIds;
+	} else {
+		return [];
+	}
+}
+
 if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSource'])) {
 	switch ($_POST['action']) {
 		case 'informRecipients':
@@ -55,7 +112,7 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 			if($shareType === \OCP\Share::SHARE_TYPE_USER) {
 				$recipientList[] = $userManager->get($recipient);
 			} elseif ($shareType === \OCP\Share::SHARE_TYPE_GROUP) {
-				$recipientList = \OC_Group::usersInGroup($recipient);
+				$recipientList = usersInGroup($recipient);
 				$group = \OC::$server->getGroupManager()->get($recipient);
 				$recipientList = $group->searchUsers('');
 			}
@@ -73,20 +130,25 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				$defaults,
 				\OC::$server->getURLGenerator()
 			);
+
 			$result = $mailNotification->sendInternalShareMail($recipientList, $itemSource, $itemType);
 
-			\OCP\Share::setSendMailStatus($itemType, $itemSource, $shareType, $recipient, true);
+			// if we were able to send to at least one recipient, mark as sent
+			// allowing the user to resend would spam users who already got a notification
+			if (count($result) < count($recipientList)) {
+				\OCP\Share::setSendMailStatus($itemType, $itemSource, $shareType, $recipient, true);
+			}
 
 			if (empty($result)) {
 				OCP\JSON::success();
 			} else {
-				OCP\JSON::error(array(
-					'data' => array(
-						'message' => $l->t("Couldn't send mail to following users: %s ",
+				OCP\JSON::error([
+					'data' => [
+						'message' => $l->t("Couldn't send mail to following recipient(s): %s ",
 								implode(', ', $result)
 								)
-						)
-					));
+					]
+				]);
 			}
 			break;
 		case 'informRecipientsDisabled':
@@ -99,14 +161,33 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 			break;
 
 		case 'email':
-			// read post variables
-			$link = (string)$_POST['link'];
-			$file = (string)$_POST['file'];
-			$to_address = (string)$_POST['toaddress'];
+			$emailBody = null;
 
+			if (isset($_POST['emailBody'])) {
+				$emailBody = trim((string)$_POST['emailBody']);
+			}
+
+			// read and filter post variables
+			$filter = new MailNotificationFilter([
+				'link' => $_POST['link'],
+				'file' => $_POST['file'],
+				'toAddress' => $_POST['toAddress'],
+				'expirationDate' => $_POST['expiration'],
+				'personalNote' => $emailBody
+			]);
+
+			$options = array();
+			$options['bcc'] = $filter->getToAddress();
+			if (isset($_POST['bccSelf']) && $_POST['bccSelf'] === 'true') {
+				$options['bcc'] .= ',' . \OC::$server->getUserSession()->getUser()->getEMailAddress();
+			}
+
+			$l10n = \OC::$server->getL10N('lib');
+
+			$sendingUser = \OC::$server->getUserSession()->getUser();
 			$mailNotification = new \OC\Share\MailNotifications(
-				\OC::$server->getUserSession()->getUser(),
-				\OC::$server->getL10N('lib'),
+				$sendingUser,
+				$l10n,
 				\OC::$server->getMailer(),
 				\OC::$server->getLogger(),
 				$defaults,
@@ -114,19 +195,30 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 			);
 
 			$expiration = null;
-			if (isset($_POST['expiration']) && $_POST['expiration'] !== '') {
+			if ($filter->getExpirationDate() !== '') {
 				try {
-					$date = new DateTime((string)$_POST['expiration']);
+					$date = new DateTime($filter->getExpirationDate());
 					$expiration = $date->getTimestamp();
 				} catch (Exception $e) {
 					\OCP\Util::writeLog('sharing', "Couldn't read date: " . $e->getMessage(), \OCP\Util::ERROR);
 				}
 			}
 
-			$result = $mailNotification->sendLinkShareMail($to_address, $file, $link, $expiration);
+			if ($emailBody !== null || $emailBody !== '') {
+				$emailBody = strip_tags($emailBody);
+			}
+			$result = $mailNotification->sendLinkShareMail(
+				null,
+				$filter->getFile(),
+				$filter->getLink(),
+				$expiration,
+				$filter->getPersonalNote(),
+				$options
+			);
+
 			if(empty($result)) {
 				// Get the token from the link
-				$linkParts = explode('/', $link);
+				$linkParts = explode('/', $filter->getLink());
 				$token = array_pop($linkParts);
 
 				// Get the share for the token
@@ -150,7 +242,7 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 								->setAuthor($currentUser)
 								->setAffectedUser($currentUser)
 								->setObject('files', $fileId, $path)
-								->setSubject(\OCA\Files_Sharing\Activity::SUBJECT_SHARED_EMAIL, [$path, $to_address]);
+								->setSubject(\OCA\Files_Sharing\Activity::SUBJECT_SHARED_EMAIL, [$path, $toAddress]);
 							\OC::$server->getActivityManager()->publish($event);
 						}
 					}
@@ -159,13 +251,13 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				\OCP\JSON::success();
 			} else {
 				$l = \OC::$server->getL10N('core');
-				OCP\JSON::error(array(
-					'data' => array(
-						'message' => $l->t("Couldn't send mail to following users: %s ",
+				OCP\JSON::error([
+					'data' => [
+						'message' => $l->t("Couldn't send mail to following recipient(s): %s ",
 								implode(', ', $result)
 							)
-					)
-				));
+					]
+				]);
 			}
 
 			break;
@@ -175,7 +267,7 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 		case 'getItemsSharedStatuses':
 			if (isset($_GET['itemType'])) {
 				$return = OCP\Share::getItemsShared((string)$_GET['itemType'], OCP\Share::FORMAT_STATUSES);
-				is_array($return) ? OC_JSON::success(array('data' => $return)) : OC_JSON::error();
+				is_array($return) ? OC_JSON::success(['data' => $return]) : OC_JSON::error();
 			}
 			break;
 		case 'getItem':
@@ -205,47 +297,61 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				} else {
 					$shares = false;
 				}
-				OC_JSON::success(array('data' => array('reshare' => $reshare, 'shares' => $shares)));
+				OC_JSON::success(['data' => ['reshare' => $reshare, 'shares' => $shares]]);
 			}
 			break;
 		case 'getShareWithEmail':
-			$result = array();
+			$result = [];
 			if (isset($_GET['search'])) {
 				$cm = OC::$server->getContactsManager();
 
-				$userEnumerationAllowed = OC::$server->getConfig()
-					->getAppValue('core', 'shareapi_allow_share_dialog_user_enumeration', 'yes') == 'yes';
+				$config = OC::$server->getConfig();
+				$userEnumerationAllowed = $config
+					->getAppValue('core', 'shareapi_allow_share_dialog_user_enumeration', 'yes') === 'yes';
+				$pattern = (string)$_GET['search'];
+				$searchConfig =  new \OCP\Util\UserSearch($config);
+				if (!$searchConfig->isSearchable($pattern)) {
+					OC_JSON::error();
+					return;
+				}
 
-				if (!is_null($cm) && $cm->isEnabled() && $userEnumerationAllowed) {
-					$contacts = $cm->search((string)$_GET['search'], array('FN', 'EMAIL'));
+				if ($cm !== null && $cm->isEnabled() && $userEnumerationAllowed) {
+					$contacts = $cm->search($pattern, ['FN', 'EMAIL']);
 					foreach ($contacts as $contact) {
+						// We don't want contacts from system address books
+						if (isset($contact['isSystemBook'])) {
+							continue;
+						}
 						if (!isset($contact['EMAIL'])) {
 							continue;
 						}
 
 						$emails = $contact['EMAIL'];
 						if (!is_array($emails)) {
-							$emails = array($emails);
+							$emails = [$emails];
 						}
 
 						foreach($emails as $email) {
-							$result[] = array(
+							$result[] = [
 								'email' => $email,
 								'displayname' => $contact['FN'],
-							);
+							];
 						}
 					}
 				}
 			}
-			OC_JSON::success(array('data' => $result));
+			OC_JSON::success(['data' => $result]);
 			break;
 		case 'getShareWith':
 			if (isset($_GET['search'])) {
 				$shareWithinGroupOnly = OC\Share\Share::shareWithGroupMembersOnly();
-				$shareWith = array();
-				$groups = OC_Group::getGroups((string)$_GET['search']);
+				$shareWith = [];
+				$groups = getGroups((string)$_GET['search']);
 				if ($shareWithinGroupOnly) {
-					$usergroups = OC_Group::getUserGroups(OC_User::getUser());
+					$usergroups = \OC::$server->getGroupManager()->getUserIdGroups(OC_User::getUser());
+					$usergroups = array_values(array_map(function(\OCP\IGroup $g) {
+						return $g->getGID();
+					}, $usergroups));
 					$groups = array_intersect($groups, $usergroups);
 				}
 
@@ -253,18 +359,18 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				$sharedGroups = [];
 				if (isset($_GET['itemShares'])) {
 					if (isset($_GET['itemShares'][OCP\Share::SHARE_TYPE_USER]) &&
-					    is_array($_GET['itemShares'][OCP\Share::SHARE_TYPE_USER])) {
+						is_array($_GET['itemShares'][OCP\Share::SHARE_TYPE_USER])) {
 						$sharedUsers = $_GET['itemShares'][OCP\Share::SHARE_TYPE_USER];
 					}
 
 					if (isset($_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP]) &&
-					    is_array($_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP])) {
+						is_array($_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP])) {
 						$sharedGroups = $_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP];
 					}
 				}
 
 				$count = 0;
-				$users = array();
+				$users = [];
 				$limit = 0;
 				$offset = 0;
 				// limit defaults to 15 if not specified via request parameter and can be no larger than 500
@@ -272,7 +378,7 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				while ($count < $request_limit && count($users) == $limit) {
 					$limit = $request_limit - $count;
 					if ($shareWithinGroupOnly) {
-						$users = OC_Group::displayNamesInGroups($usergroups, (string)$_GET['search'], $limit, $offset);
+						$users = displayNamesInGroups($usergroups, (string)$_GET['search'], $limit, $offset);
 					} else {
 						$users = OC_User::getDisplayNames((string)$_GET['search'], $limit, $offset);
 					}
@@ -287,12 +393,12 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 							|| !is_array($_GET['itemShares'][OCP\Share::SHARE_TYPE_USER])
 							|| !in_array($uid, $_GET['itemShares'][OCP\Share::SHARE_TYPE_USER]))
 							&& $uid != OC_User::getUser()) {
-							$shareWith[] = array(
+							$shareWith[] = [
 								'label' => $displayName,
-								'value' => array(
+								'value' => [
 									'shareType' => OCP\Share::SHARE_TYPE_USER,
-									'shareWith' => $uid)
-							);
+									'shareWith' => $uid]
+							];
 							$count++;
 						}
 					}
@@ -312,13 +418,13 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 							|| !isset($_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP])
 							|| !is_array($_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP])
 							|| !in_array($group, $_GET['itemShares'][OCP\Share::SHARE_TYPE_GROUP])) {
-							$shareWith[] = array(
+							$shareWith[] = [
 								'label' => $group,
-								'value' => array(
+								'value' => [
 									'shareType' => OCP\Share::SHARE_TYPE_GROUP,
 									'shareWith' => $group
-								)
-							);
+								]
+							];
 							$count++;
 						}
 					} else {
@@ -330,26 +436,26 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				$backend = \OCP\Share::getBackend((string)$_GET['itemType']);
 				if ($backend->isShareTypeAllowed(\OCP\Share::SHARE_TYPE_REMOTE)) {
 					if (substr_count((string)$_GET['search'], '@') >= 1) {
-						$shareWith[] = array(
+						$shareWith[] = [
 							'label' => (string)$_GET['search'],
-							'value' => array(
+							'value' => [
 								'shareType' => \OCP\Share::SHARE_TYPE_REMOTE,
 								'shareWith' => (string)$_GET['search']
-							)
-						);
+							]
+						];
 					}
 					$contactManager = \OC::$server->getContactsManager();
 					$addressBookContacts = $contactManager->search($_GET['search'], ['CLOUD', 'FN']);
 					foreach ($addressBookContacts as $contact) {
 						if (isset($contact['CLOUD'])) {
 							foreach ($contact['CLOUD'] as $cloudId) {
-								$shareWith[] = array(
+								$shareWith[] = [
 									'label' => $contact['FN'] . ' (' . $cloudId . ')',
-									'value' => array(
+									'value' => [
 										'shareType' => \OCP\Share::SHARE_TYPE_REMOTE,
 										'shareWith' => $cloudId
-									)
-								);
+									]
+								];
 							}
 						}
 					}
@@ -369,8 +475,8 @@ if (isset($_POST['action']) && isset($_POST['itemType']) && isset($_POST['itemSo
 				$sorter = new \OC\Share\SearchResultSorter((string)$_GET['search'],
 														   'label',
 														   \OC::$server->getLogger());
-				usort($shareWith, array($sorter, 'sort'));
-				OC_JSON::success(array('data' => $shareWith));
+				usort($shareWith, [$sorter, 'sort']);
+				OC_JSON::success(['data' => $shareWith]);
 			}
 			break;
 	}
