@@ -1,6 +1,14 @@
 OC.L10N.register(
     "core",
     {
+    "No image or file provided" : "Ez da irudi edo fitxategirik zehaztu",
+    "Unknown filetype" : "Fitxategi mota ezezaguna",
+    "Invalid image" : "Baliogabeko irudia",
+    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik, saiatu berriro",
+    "No crop data provided" : "Ez da ebaketarako daturik zehaztu",
+    "Couldn't reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
+    "%s password reset" : "%s pasahitza berrezarri",
+    "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
     "Couldn't send mail to following users: %s " : "Ezin izan da posta bidali hurrengo erabiltzaileei: %s",
     "Turned on maintenance mode" : "Mantenu modua gaitu da",
     "Turned off maintenance mode" : "Mantenu modua desgaitu da",
@@ -8,12 +16,6 @@ OC.L10N.register(
     "Checked database schema update" : "Egiaztatuta datu-basearen zerbitzariaren eguneraketa",
     "Checked database schema update for apps" : "Egiaztatuta aplikazioen datu-basearen zerbitzariaren eguneraketa",
     "Updated \"%s\" to %s" : "\"%s\" %s-ra eguneratua",
-    "Disabled incompatible apps: %s" : "Bateragarriak ez diren desgaitutako aplikazioak: %s",
-    "No image or file provided" : "Ez da irudi edo fitxategirik zehaztu",
-    "Unknown filetype" : "Fitxategi mota ezezaguna",
-    "Invalid image" : "Baliogabeko irudia",
-    "No temporary profile picture available, try again" : "Ez dago behin-behineko profil irudirik, saiatu berriro",
-    "No crop data provided" : "Ez da ebaketarako daturik zehaztu",
     "Sunday" : "Igandea",
     "Monday" : "Astelehena",
     "Tuesday" : "Asteartea",
@@ -21,6 +23,15 @@ OC.L10N.register(
     "Thursday" : "Osteguna",
     "Friday" : "Ostirala",
     "Saturday" : "Larunbata",
+    "Sun." : "ig.",
+    "Mon." : "al.",
+    "Tue." : "ar.",
+    "Wed." : "az.",
+    "Thu." : "og.",
+    "Fri." : "ol.",
+    "Sat." : "lr.",
+    "Su" : "Ig",
+    "Sa" : "La",
     "January" : "Urtarrila",
     "February" : "Otsaila",
     "March" : "Martxoa",
@@ -33,9 +44,21 @@ OC.L10N.register(
     "October" : "Urria",
     "November" : "Azaroa",
     "December" : "Abendua",
+    "Jan." : "urt.",
+    "Feb." : "ots.",
+    "Mar." : "mar.",
+    "Apr." : "api.",
+    "May." : "mai.",
+    "Jun." : "eka.",
+    "Jul." : "uzt.",
+    "Aug." : "abu.",
+    "Sep." : "ira.",
+    "Oct." : "urr.",
+    "Nov." : "aza.",
+    "Dec." : "abe.",
     "Settings" : "Ezarpenak",
     "Saving..." : "Gordetzen...",
-    "Couldn't send reset email. Please contact your administrator." : "Ezin da berrezartzeko eposta bidali. Mesedez jarri harremetan zure administradorearekin.",
+    "seconds ago" : "segundu",
     "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Zure pasahitza berrezartzeko lotura zure postara bidalia izan da.<br>Ez baduzu arrazoizko denbora epe batean jasotzen begiratu zure zabor-posta karpetan.<br>Hor ere ez badago kudeatzailearekin harremanetan jarri.",
     "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Zure fitxategiak enkriptaturik daude. Ez baduzu berreskuratze gakoa gaitzen pasahitza berrabiaraztean ez da zure fitxategiak berreskuratzeko modurik egongo. <br />Zer egin ziur ez bazaude kudeatzailearekin harremanetan ipini jarraitu aurretik.<br /> Ziur zaude aurrera jarraitu nahi duzula?",
     "I know what I'm doing" : "Badakit zer ari naizen egiten",
@@ -63,54 +86,47 @@ OC.L10N.register(
     "So-so password" : "Halamoduzko pasahitza",
     "Good password" : "Pasahitz ona",
     "Strong password" : "Pasahitz sendoa",
-    "Your web server is not yet properly setup to allow files synchronization because the WebDAV interface seems to be broken." : "Zure web zerbitzaria ez dago oraindik ongi konfiguratuta fitxategien sinkronizazioa egiteko, WebDAV interfazea ongi ez dagoela dirudi.",
-    "This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." : "Zerbitzari honen interneteko konexioa ez dabil. Honek esan nahi du kanpoko biltegiratze zerbitzuak, eguneraketen informazioa edo bestelako aplikazioen instalazioa bezalako programek ez dutela funtzionatuko. Urrunetik fitxategiak eskuratzea eta e-postak bidaltzea ere ezinezkoa izan daiteke. onwCloud-en aukera guztiak erabili ahal izateko zerbitzari honetan interneteko konexioa gaitzea aholkatzen dizugu.",
-    "Your data directory and your files are probably accessible from the internet. The .htaccess file is not working. We strongly suggest that you configure your webserver in a way that the data directory is no longer accessible or you move the data directory outside the webserver document root." : "Zure data karpeta eta zure fitxategiak internetetik zuzenean eskuragarri egon daitezke.  .htaccess fitxategia ez du bere lana egiten. Aholkatzen dizugu zure web zerbitzaria ongi konfiguratzea data karpeta eskuragarri ez izateko edo data karpeta web zerbitzariaren dokumentu errotik mugitzea.",
     "Error occurred while checking server setup" : "Errore bat gertatu da zerbitzariaren konfigurazioa egiaztatzerakoan.",
     "Shared" : "Elkarbanatuta",
     "Shared with {recipients}" : "{recipients}-rekin partekatua.",
-    "Share" : "Elkarbanatu",
     "Error" : "Errorea",
     "Error while sharing" : "Errore bat egon da elkarbanatzean",
     "Error while unsharing" : "Errore bat egon da elkarbanaketa desegitean",
-    "Error while changing permissions" : "Errore bat egon da baimenak aldatzean",
-    "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
-    "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
-    "Share with user or group …" : "Elkarbanatu erabiltzaile edo taldearekin...",
-    "Share link" : "Elkarbanatu lotura",
     "The public link will expire no later than {days} days after it is created" : "Esteka publikoak iraungi egingo du, askoz jota, sortu eta  {days} egunetara.",
-    "Link" : "Esteka",
-    "Password protect" : "Babestu pasahitzarekin",
-    "Password" : "Pasahitza",
-    "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
-    "Allow editing" : "Baimendu editatzea",
-    "Email link to person" : "Postaz bidali lotura ",
-    "Send" : "Bidali",
     "Set expiration date" : "Ezarri muga data",
     "Expiration" : "Iraungitzea",
     "Expiration date" : "Muga data",
-    "Adding user..." : "Erabiltzailea gehitzen...",
+    "Link" : "Esteka",
+    "Edit" : "Editatu",
+    "Remove" : "Ezabatu",
+    "Choose a password for the public link" : "Aukeratu pasahitz bat esteka publikorako",
+    "Password" : "Pasahitza",
+    "Name" : "Izena",
+    "Allow editing" : "Baimendu editatzea",
+    "Save" : "Gorde",
+    "Sending ..." : "Bidaltzen ...",
+    "Email sent" : "Eposta bidalia",
+    "Email link to person" : "Postaz bidali lotura ",
+    "Shared with you and the group {group} by {owner}" : "{owner}-k zu eta {group} taldearekin elkarbanatuta",
+    "Shared with you by {owner}" : "{owner}-k zurekin elkarbanatuta",
     "group" : "taldea",
     "remote" : "urrunekoa",
-    "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
-    "Shared in {item} with {user}" : "{user}ekin {item}-n elkarbanatuta",
-    "Unshare" : "Ez elkarbanatu",
     "notify by email" : "jakinarazi eposta bidez",
+    "Unshare" : "Ez elkarbanatu",
     "can share" : "elkarbana dezake",
     "can edit" : "editatu dezake",
-    "access control" : "sarrera kontrola",
     "create" : "sortu",
     "change" : "aldatu",
     "delete" : "ezabatu",
-    "Password protected" : "Pasahitzarekin babestuta",
-    "Error unsetting expiration date" : "Errorea izan da muga data kentzean",
-    "Error setting expiration date" : "Errore bat egon da muga data ezartzean",
-    "Sending ..." : "Bidaltzen ...",
-    "Email sent" : "Eposta bidalia",
+    "access control" : "sarrera kontrola",
+    "Share" : "Elkarbanatu",
+    "Resharing is not allowed" : "Berriz elkarbanatzea ez dago baimendua",
+    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Partekatu beste ownClud-en jendearekin sintaxi honekin erabiltzaleizena@adibidea.com/owncloud",
     "Warning" : "Abisua",
+    "Delete" : "Ezabatu",
+    "Rename" : "Berrizendatu",
     "The object type is not specified." : "Objetu mota ez dago zehaztuta.",
     "Enter new" : "Sartu berria",
-    "Delete" : "Ezabatu",
     "Add" : "Gehitu",
     "Edit tags" : "Editatu etiketak",
     "Error loading dialog template: {error}" : "Errorea elkarrizketa txantiloia kargatzean: {errorea}",
@@ -121,39 +137,17 @@ OC.L10N.register(
     "Hello {name}, the weather is {weather}" : "Kaixo {name}, eguraldia {weather} da",
     "Hello {name}" : "Kaixo {name}",
     "_download %n file_::_download %n files_" : ["%n fitxategia jaitsi","jaitsi %n fitxategiak"],
-    "Updating {productName} to version {version}, this may take a while." : "Eguneratu  {productName} {version} bertsiora, bere denbora behar du.",
+    "An error occurred." : "Errore bat gertatu da.",
     "Please reload the page." : "Mesedez birkargatu orria.",
-    "The update was unsuccessful. " : "Eguneraketa ongi burutu da.",
+    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Eguneraketa ez da ongi egin. Mesedez egin arazoaren txosten bat <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud komunitatearentzako</a>.",
     "The update was successful. Redirecting you to ownCloud now." : "Eguneraketa ongi egin da. Orain zure ownClouderea berbideratua izango zara.",
-    "Couldn't reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
-    "Couldn't send reset email. Please make sure your username is correct." : "Ezin izan da berrezartzeko eposta bidali. Ziurtatu zure erabiltzaile izena egokia dela.",
-    "Couldn't send reset email because there is no email address for this username. Please contact your administrator." : "Ezin izan da berrezartzeko eposta bidali erabiltzaile izen honetarako eposta helbiderik ez dagoelako. Mesedez harremanetan jarri kudeatzailearekin.",
-    "%s password reset" : "%s pasahitza berrezarri",
-    "Use the following link to reset your password: {link}" : "Eribili hurrengo lotura zure pasahitza berrezartzeko: {link}",
-    "New password" : "Pasahitz berria",
-    "New Password" : "Pasahitz Berria",
-    "Reset password" : "Berrezarri pasahitza",
     "Searching other places" : "Beste lekuak bilatzen",
-    "No search result in other places" : "Ez da bilaketaren emaitzik lortu beste lekuetan",
-    "_{count} search result in other places_::_{count} search results in other places_" : ["Bilaketa emaitza {count} beste lekuetan","{count} emaitza lortu dira beste lekuetan"],
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X-ek ez du sostengurik eta %s gaizki ibili daiteke plataforma honetan. Erabiltzekotan, zure ardurapean.",
-    "For the best results, please consider using a GNU/Linux server instead." : "Emaitza hobeak izateko, mesedez gogoan hartu GNU/Linux zerbitzari bat erabiltzea.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4GB and is highly discouraged." : "Dirudi %s instantzia hau 32biteko PHP ingurunean ari dela eta open_basedir php.ini fitxategian konfiguratu dela. Honek 4GB baino gehiagoko fitxategiekin arazoak sor ditzake eta ez da aholkatzen.",
-    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Mesedez ezabatu open_basedir ezarpena zure php.ini-tik edo aldatu 64-biteko PHPra.",
-    "It seems that this %s instance is running on a 32-bit PHP environment and cURL is not installed. This will lead to problems with files over 4GB and is highly discouraged." : "Dirudi %s instantzia hau 32-biteko PHP inguruan ari dela eta cURL ez dago instalaturik.  Honek 4GB baino gehiagoko fitxategiekin arazoak sor ditzake eta ez da aholkatzen.",
-    "Please install the cURL extension and restart your webserver." : "Mesedez instalatu cURL extensioa eta berrabiarazi zure web zerbitzaria.",
+    "No search results in other folders" : "Ez da bilaketaren emaitzik lortu beste karpetatan",
     "Personal" : "Pertsonala",
     "Users" : "Erabiltzaileak",
     "Apps" : "Aplikazioak",
     "Admin" : "Admin",
     "Help" : "Laguntza",
-    "Error loading tags" : "Errore bat izan da etiketak kargatzearkoan.",
-    "Tag already exists" : "Etiketa dagoeneko existitzen da",
-    "Error deleting tag(s)" : "Errore bat izan da etiketa(k) ezabatzerakoan",
-    "Error tagging" : "Errorea etiketa ezartzerakoan",
-    "Error untagging" : "Errorea etiketa kentzerakoan",
-    "Error favoriting" : "Errorea gogokoetara gehitzerakoan",
-    "Error unfavoriting" : "Errorea gogokoetatik kentzerakoan",
     "Access forbidden" : "Sarrera debekatuta",
     "File not found" : "Ez da fitxategia aurkitu",
     "The specified document has not been found on the server." : "Zehaztutako dokumentua ez da zerbitzarian aurkitu.",
@@ -173,11 +167,6 @@ OC.L10N.register(
     "File: %s" : "Fitxategia: %s",
     "Line: %s" : "Lerroa: %s",
     "Trace" : "Arrastoa",
-    "Security Warning" : "Segurtasun abisua",
-    "Your PHP version is vulnerable to the NULL Byte attack (CVE-2006-7243)" : "Zure PHP bertsioa NULL Byte erasoak (CVE-2006-7243) mendera dezake.",
-    "Please update your PHP installation to use %s securely." : "Mesedez eguneratu zure PHP instalazioa %s seguru erabiltzeko",
-    "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "Zure data karpeta eta fitxategiak interneten bidez eskuragarri egon daitezke .htaccess fitxategia ez delako funtzionatzen ari.",
-    "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\">documentation</a>." : "Zure zerbitrzaria ongi konfiguratzeko, mezedez <a href=\"%s\" target=\"_blank\">dokumentazioa</a> ikusi.",
     "Create an <strong>admin account</strong>" : "Sortu <strong>kudeatzaile kontu<strong> bat",
     "Username" : "Erabiltzaile izena",
     "Storage & database" : "Biltegia & datubasea",
@@ -191,32 +180,69 @@ OC.L10N.register(
     "Database host" : "Datubasearen hostalaria",
     "Finish setup" : "Bukatu konfigurazioa",
     "Finishing …" : "Bukatzen...",
-    "This application requires JavaScript for correct operation. Please <a href=\"http://enable-javascript.com/\" target=\"_blank\">enable JavaScript</a> and reload the page." : "Aplikazio honek ongi funtzionatzeko JavaScript behar du. Mesedez  <a href=\"http://enable-javascript.com/\" target=\"_blank\">gaitu JavaScript</a> eta birkargatu orri hau.",
-    "%s is available. Get more information on how to update." : "%s erabilgarri dago. Eguneratzeaz argibide gehiago eskuratu.",
+    "Need help?" : "Laguntza behar al duzu?",
+    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Kaixo<br><br>%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s",
     "Log out" : "Saioa bukatu",
     "Search" : "Bilatu",
     "Server side authentication failed!" : "Zerbitzari aldeko autentifikazioak huts egin du!",
     "Please contact your administrator." : "Mesedez jarri harremetan zure administradorearekin.",
-    "Forgot your password? Reset it!" : "Pasahitza ahaztu duzu? Berrezarri!",
-    "remember" : "gogoratu",
     "Log in" : "Hasi saioa",
     "Alternative Logins" : "Beste erabiltzaile izenak",
-    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Kaixo<br><br>%s-ek %s zurekin partekatu duela jakin dezazun.\nIkusi ezazu: %s",
+    "Use the following link to reset your password: {link}" : "Eribili hurrengo lotura zure pasahitza berrezartzeko: {link}",
+    "New password" : "Pasahitz berria",
+    "New Password" : "Pasahitz Berria",
+    "Reset password" : "Berrezarri pasahitza",
     "This ownCloud instance is currently in single user mode." : "ownCloud instantzia hau erabiltzaile bakar moduan dago.",
     "This means only administrators can use the instance." : "Honek administradoreak bakarrik erabili dezakeela esan nahi du.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Jarri harremanetan zure sistema administratzailearekin mezu hau irauten badu edo bat-batean agertu bada.",
     "Thank you for your patience." : "Milesker zure patzientziagatik.",
     "You are accessing the server from an untrusted domain." : "Zerbitzaria domeinu ez fidagarri batetik eskuratzen ari zara.",
-    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domain\" setting in config/config.php. An example configuration is provided in config/config.sample.php." : "Mesedez harremanetan jarri kudeatzailearekin. Zu kudeatzailea bazara, konfiguratu \"trusted_domain\" ezarpena config/config.php fitxategian. Adibidezko konfigurazko bat  config/config.sample.php fitxategian dago.",
     "Depending on your configuration, as an administrator you might also be able to use the button below to trust this domain." : "Zure ezarpenen gorabehera, administratzaile bezala posible duzu ere azpiko botoia erabiltzea fidatzeko domeinu horrekin.",
     "Add \"%s\" as trusted domain" : "Gehitu \"%s\" domeinu fidagarri gisa",
-    "%s will be updated to version %s." : "%s %s bertsiora eguneratuko da.",
-    "The following apps will be disabled:" : "Ondorengo aplikazioak desgaituko dira:",
     "The theme %s has been disabled." : "%s gaia desgaitu da.",
     "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Ekin aurretik egiazta ezazu datu basearen, ezarpenen karpetaren eta datuen karpetaren babeskopia duzula.",
     "Start update" : "Hasi eguneraketa",
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Instalazio handien itxarote-denbora saihesteko, ondoko komandoa exekuta dezakezu instalazio direktoriotik:",
-    "This %s instance is currently being updated, which may take a while." : "%s instantzia hau eguneratzen ari da, honek denbora har dezake.",
-    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean."
+    "This page will refresh itself when the %s instance is available again." : "Orri honek bere burua eguneratuko du %s instantzia berriz prest dagoenean.",
+    "No valid crop data provided" : "Ebaketarako datu baliogabea",
+    "Crop is not square" : "Ebaketa ez da karratua",
+    "Could not reset password because the token is invalid" : "Ezin izan da pasahitza berrezarri tokena baliogabea delako",
+    "Could not reset password because the token expired" : "Ezin izan da pasahitza berrezarri tokena iraungi delako",
+    "Could not reset password because the token does not match" : "Ezin izan da pasahitza berrezarri tokena ez datorrelako bat",
+    "Preparing update" : "Eguneraketa prestatzen",
+    "Create public link" : "Esteka publikoa sortu",
+    "Copy to clipboard" : "Kopiatu arbelera",
+    "Anyone with the link has access to the file/folder" : "Esteka duen edonork atzitu dezake fitxategi/karpeta",
+    "Filename" : "Fitxategiaren izena",
+    "User and Groups" : "Erabiltzaile eta Taldeak",
+    "Menu" : "Menua",
+    "Invalid file provided" : "Baliogabeko fitxategia",
+    "File is too big" : "Fitxategia handiegia da",
+    "Collaborative tags" : "Kolaboraziorako etiketak",
+    "Please select a file." : "Mesedez, hautatu fitxategia.",
+    "An error occurred. Please contact your admin." : "Errore bat gertatu da. Mesedez jarri harremanetan zure administratzailearekin.",
+    "%s password changed successfully" : "%s pasahitza behar bezala aldatu da",
+    "[%d / %d]: %s" : "[%d / %d]: %s",
+    "Repair warning: " : "Konponketa abisua:",
+    "Repair error: " : "Konponketa errorea:",
+    "Checking updates of apps" : "Aplikazioentzat eguneraketak baieztatzen",
+    "%s (3rdparty)" : "%s (3garrena)",
+    "%s (incompatible)" : "%s (bateraezina)",
+    "Following apps have been disabled: %s" : "Hurrengo aplikazioak desgaitu dira: %s",
+    "Already up to date" : "Dagoeneko martxan",
+    "Mo" : "Al",
+    "Tu" : "Ar",
+    "We" : "Az",
+    "Th" : "Og",
+    "Fr" : "Ol",
+    "Dismiss" : "Baztertu",
+    "Press ⌘-C to copy." : "Sakatu ⌘-C kopiatzeko.",
+    "Press Ctrl-C to copy." : "Sakatu Ctrl-C kopiatzeko.",
+    "Updating database schema" : "Datu-base eskema eguneratzen",
+    "Error adding {addItem}: {addItem} already exists" : "{addItem} gehitzean errorea: {addItem} dagoeneko bada",
+    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Datu-base eskema eguneratu daiteken baieztatzen (dabu-base tamainaren arabera denbora luzea eraman dezake honek)",
+    "Reset log level" : "Log maila berrezarri",
+    "Starting code integrity check" : "Kode osotasun baieztapena hasten",
+    "Finished code integrity check" : "Kode osotasun baieztapena amaituta"
 },
 "nplurals=2; plural=(n != 1);");
