@@ -2,13 +2,14 @@ OC.L10N.register(
     "lib",
     {
     "Cannot write into \"config\" directory!" : "Kan ikke skrive til mappen \"config\"!",
-    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan normalvis ordnes ved at give webserveren skrive adgang til config mappen",
+    "This can usually be fixed by giving the webserver write access to the config directory" : "Dette kan som regel ordnes ved at give webserveren skrive adgang til config mappen",
     "See %s" : "Se %s",
     "This can usually be fixed by %sgiving the webserver write access to the config directory%s." : "Dette kan som regel rettes ved at %sgive webserveren skriveadgang til config-mappen%s.",
     "Sample configuration detected" : "Eksempel for konfiguration registreret",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "Der er registreret at eksempel for konfiguration er blevet kopieret. Dette kan ødelægge din installation og understøttes ikke. Læs venligst dokumentationen før der foretages ændringer i config.php",
     "PHP %s or higher is required." : "Der kræves PHP %s eller nyere.",
     "PHP with a version lower than %s is required." : "Der kræves PHP %s eller ældre.",
+    "%sbit or higher PHP required." : "%sbit eller højere PHP er påkrævet.",
     "Following databases are supported: %s" : "Følgende databaser understøttes: %s",
     "The command line tool %s could not be found" : "Kommandolinjeværktøjet %s blev ikke fundet",
     "The library %s is not available." : "Biblioteket %s er ikke tilgængeligt.",
@@ -16,18 +17,10 @@ OC.L10N.register(
     "Library %s with a version lower than %s is required - available version %s." : "Der kræves en version af biblioteket %s, der er lavere end %s - tilgængelig version er %s.",
     "Following platforms are supported: %s" : "Følgende platforme understøttes: %s",
     "ownCloud %s or higher is required." : "Der kræves ownCloud %s eller højere.",
-    "ownCloud with a version lower than %s is required." : "Der kræves ownCloud i en version som er lavere end %s.",
-    "Help" : "Hjælp",
-    "Personal" : "Personligt",
-    "Settings" : "Indstillinger",
-    "Users" : "Brugere",
-    "Admin" : "Admin",
-    "Recommended" : "Anbefalet",
-    "App \\\"%s\\\" can't be installed because it is not compatible with this version of ownCloud." : "App'en \\\"%s\\\" kan ikke installeres, da den ikke er kompatible med denne version af ownCloud.",
-    "App \\\"%s\\\" cannot be installed because the following dependencies are not fulfilled: %s" : "Programmet \\\"%s\\\" kan ikke installeres, da følgende afhængigheder ikke er opfyldt: %s",
-    "No app name specified" : "Intet app-navn angivet",
+    "ownCloud %s or lower is required." : "ownCloud %s eller lavere er påkrævet.",
     "Unknown filetype" : "Ukendt filtype",
     "Invalid image" : "Ugyldigt billede",
+    "Avatar image is not square" : "Avatar billede er ikke kvadratisk",
     "today" : "i dag",
     "yesterday" : "i går",
     "_%n day ago_::_%n days ago_" : ["%n dag siden","%n dage siden"],
@@ -38,101 +31,154 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n time siden","%n timer siden"],
     "_%n minute ago_::_%n minutes ago_" : ["%n minut siden","%n minutter siden"],
     "seconds ago" : "sekunder siden",
-    "Database Error" : "Databasefejl",
-    "Please contact your system administrator." : "Kontakt venligst din systemadministrator.",
-    "web services under your control" : "Webtjenester under din kontrol",
+    "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Modulet med id'et %s findes ikke. Slå det venligst til i dine app-indstillinger eller kontakt din administrator.",
+    "Builtin" : "Indbygget",
+    "None" : "Ingen",
+    "Username and password" : "Brugernavn og kodeord",
+    "Username" : "Brugernavn",
+    "Password" : "Kodeord",
+    "Log-in credentials, save in session" : "Log ind oplysningerne, er gemt i sessioncookies",
+    "Empty filename is not allowed" : "Tomme filnavne er ikke tilladt",
+    "Dot files are not allowed" : "Filer med punktummer er ikke tilladt",
+    "4-byte characters are not supported in file names" : "Tegn med 4-byte understøttes ikke i filnavne",
+    "File name is a reserved word" : "Filnavnet er et reserveret ord",
+    "File name contains at least one invalid character" : "Filnavnet indeholder mindst ét ugyldigt tegn",
+    "File name is too long" : "Filnavnet er for langt",
     "App directory already exists" : "App-mappe findes allerede",
     "Can't create app folder. Please fix permissions. %s" : "Kan ikke oprette app-mappe. Ret tilladelser. %s",
+    "Archive does not contain a directory named %s" : "Arkivet indeholder ike en mappe kaldet %s",
     "No source specified when installing app" : "Ingen kilde angivet under installation af app",
     "No href specified when installing app from http" : "Ingen href angivet under installation af app via http",
     "No path specified when installing app from local file" : "Ingen sti angivet under installation af app fra lokal fil",
     "Archives of type %s are not supported" : "Arkiver af type %s understøttes ikke",
     "Failed to open archive when installing app" : "Kunne ikke åbne arkiv under installation af appen",
     "App does not provide an info.xml file" : "Der følger ingen info.xml-fil med appen",
+    "App cannot be installed because appinfo file cannot be read." : "App kan ikke installeres, fordi appinfo filen ikke kan læses.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Signaturen kunne ikke kontrolleres. Kontakt venligst app udvikleren og tjek din admin skærm.",
     "App can't be installed because of not allowed code in the App" : "Appen kan ikke installeres, da den indeholder ikke-tilladt kode",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Appen kan ikke installeres, da den ikke er kompatibel med denne version af ownCloud.",
     "App can't be installed because it contains the <shipped>true</shipped> tag which is not allowed for non shipped apps" : "Appen kan ikke installeres, da den indeholder mærket <shipped>true</shipped>, hvilket ikke er tilladt for ikke-medfølgende apps",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "App kan ikke installeres, da versionen i info.xml/version ikke er den samme som versionen rapporteret fra app-storen",
-    "Application is not enabled" : "Programmet er ikke aktiveret",
-    "Authentication error" : "Adgangsfejl",
-    "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
-    "Unknown user" : "Ukendt bruger",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "App kan ikke installeres, fordi den version i info.xml er ikke det samme som den version rapporteret fra app-butikken",
+    "Apps" : "Apps",
+    "General" : "Generelt",
+    "Storage" : "Opbevaring",
+    "Security" : "Sikkerhed",
+    "Encryption" : "Kryptering",
+    "Sharing" : "Deling",
+    "Search" : "Søg",
+    "Updates" : "Opdateringer",
+    "Additional" : "ekstra",
+    "%s enter the database username and name." : "%s indtast databasens brugernavn og navn.",
     "%s enter the database username." : "%s indtast database brugernavnet.",
     "%s enter the database name." : "%s indtast database navnet.",
     "%s you may not use dots in the database name" : "%s du må ikke bruge punktummer i databasenavnet.",
-    "MS SQL username and/or password not valid: %s" : "MS SQL brugernavn og/eller adgangskode ikke er gyldigt: %s",
-    "You need to enter either an existing account or the administrator." : "Du bliver nødt til at indtaste en eksisterende bruger eller en administrator.",
-    "MySQL/MariaDB username and/or password not valid" : "Ugyldigt MySQL/MariaDB brugernavn og/eller kodeord ",
-    "DB Error: \"%s\"" : "Databasefejl: \"%s\"",
-    "Offending command was: \"%s\"" : "Fejlende kommando var: \"%s\"",
-    "MySQL/MariaDB user '%s'@'localhost' exists already." : "MySQL/MariaDB bruger '%s'@'localhost' eksistere allerede.",
-    "Drop this user from MySQL/MariaDB" : "Slet denne bruger fra MySQL/MariaDB",
-    "MySQL/MariaDB user '%s'@'%%' already exists" : "MySQL/MariaDB bruger '%s'@'%%' eksistere allerede",
-    "Drop this user from MySQL/MariaDB." : "Drop denne bruger fra MySQL/MariaDB.",
     "Oracle connection could not be established" : "Oracle forbindelsen kunne ikke etableres",
     "Oracle username and/or password not valid" : "Oracle brugernavn og/eller kodeord er ikke gyldigt.",
+    "DB Error: \"%s\"" : "Databasefejl: \"%s\"",
+    "Offending command was: \"%s\"" : "Fejlende kommando var: \"%s\"",
+    "You need to enter either an existing account or the administrator." : "Du bliver nødt til at indtaste en eksisterende bruger eller en administrator.",
     "Offending command was: \"%s\", name: %s, password: %s" : "Fejlende kommando var: \"%s\", navn: %s, password: %s",
     "PostgreSQL username and/or password not valid" : "PostgreSQL brugernavn og/eller kodeord er ikke gyldigt.",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X understøttes ikke og %s vil ikke virke optimalt på denne platform. Anvend på eget ansvar!",
+    "For the best results, please consider using a GNU/Linux server instead." : "For de bedste resultater, overvej venligst at bruge en GNU/Linux-server i stedet.",
+    "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det ser ud til, at denne %s-instans kører på et 32-bit PHP-miljø, samt at open_basedir er blevet konfigureret gennem php.ini. Dette vil føre til problemer med filer som er større end 4GB, og frarådes kraftigt.",
+    "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Fjern venligst indstillingen for open_basedir inde i din php.ini eller skift til 64-bit PHP.",
     "Set an admin username." : "Angiv et admin brugernavn.",
     "Set an admin password." : "Angiv et admin kodeord.",
     "Can't create or write into the data directory %s" : "Kan ikke oprette eller skrive ind i datamappen %s",
+    "Invalid Federated Cloud ID" : "Ugyldigt Federated Cloud ID",
     "%s shared »%s« with you" : "%s delte »%s« med dig",
+    "%s via %s" : "%s via %s",
     "Sharing %s failed, because the backend does not allow shares from type %i" : "Deling af %s mislykkedes, fordi backenden ikke tillader delinger fra typen %i",
     "Sharing %s failed, because the file does not exist" : "Deling af %s mislykkedes, fordi filen ikke eksisterer",
     "You are not allowed to share %s" : "Du har ikke tilladelse til at dele %s",
-    "Sharing %s failed, because the user %s is the item owner" : "Der skete en fejl ved deling af %s, brugeren %s er ejer af objektet",
+    "Sharing %s failed, because you can not share with yourself" : "Deling af %s mislykkedes, fordi du ikke kan dele med dig selv",
     "Sharing %s failed, because the user %s does not exist" : "Der skete en fejl ved deling af %s, brugeren %s eksistere ikke",
     "Sharing %s failed, because the user %s is not a member of any groups that %s is a member of" : "Der skete en fejl ved deling af %s, brugeren %s er ikke medlem af nogle grupper som %s er medlem af",
     "Sharing %s failed, because this item is already shared with %s" : "Der skete en fejl ved deling af %s, objektet er allerede delt med %s",
+    "Sharing %s failed, because this item is already shared with user %s" : "Deling af %s mislykkedes, fordi dette element allerede er delt med brugeren %s",
     "Sharing %s failed, because the group %s does not exist" : "Der skete en fejl ved deling af %s, gruppen %s eksistere ikke",
     "Sharing %s failed, because %s is not a member of the group %s" : "Der skete en fejl ved deling af %s, fordi %s ikke er medlem af gruppen %s",
     "You need to provide a password to create a public link, only protected links are allowed" : "Du skal angive et kodeord for at oprette et offentligt link - kun beskyttede links er tilladt",
     "Sharing %s failed, because sharing with links is not allowed" : "Der skete en fejl ved deling af %s, det er ikke tilladt at dele links",
+    "Not allowed to create a federated share with the same user" : "Det er ikke tilladt at danne et datafællesskab med samme bruger",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Deling af %s mislykkedes - kunne ikke finde %s. Måske er serveren ikke tilgængelig i øjeblikket.",
     "Share type %s is not valid for %s" : "Delingstypen %s er ikke gyldig for %s",
     "Setting permissions for %s failed, because the permissions exceed permissions granted to %s" : "Angivelse af tilladelser for %s mislykkedes, fordi tilladelserne overskred de som var tildelt %s",
     "Setting permissions for %s failed, because the item was not found" : "Angivelse af tilladelser for %s mislykkedes, fordi artiklen ikke blev fundet",
     "Cannot set expiration date. Shares cannot expire later than %s after they have been shared" : "Kan ikke angive udløbsdato. Delinger kan ikke udløbe senere end %s efter at de er blevet delt",
     "Cannot set expiration date. Expiration date is in the past" : "Kan ikke angive udløbsdato. Udløbsdato er allerede passeret",
+    "Cannot clear expiration date. Shares are required to have an expiration date." : "Kan ikke rydde udløbsdatoen. Det er et krav til delinger, at de har en udløbsdato.",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delingsbackend'en %s skal implementere grænsefladen OCP\\Share_Backend",
     "Sharing backend %s not found" : "Delingsbackend'en %s blev ikke fundet",
     "Sharing backend for %s not found" : "Delingsbackend'en for %s blev ikke fundet",
-    "Sharing %s failed, because the user %s is the original sharer" : "Deling af %s mislykkedes, fordi brugeren %s er den som delte oprindeligt",
+    "Sharing failed, because the user %s is the original sharer" : "Deling mislykkedes, fordi brugeren %s er den som delte oprindeligt",
     "Sharing %s failed, because the permissions exceed permissions granted to %s" : "Deling af %s mislykkedes, fordi tilladelserne overskred de tillaldelser som %s var tildelt",
     "Sharing %s failed, because resharing is not allowed" : "Deling af %s mislykkedes, fordi videredeling ikke er tilladt",
     "Sharing %s failed, because the sharing backend for %s could not find its source" : "Deling af %s mislykkedes, fordi back-enden ikke kunne finde kilden til %s",
     "Sharing %s failed, because the file could not be found in the file cache" : "Deling af %s mislykkedes, fordi filen ikke kunne findes i fil-cachen",
+    "Cannot increase permissions of %s" : "Kan give yderigere rettigheder til %s",
+    "Files can't be shared with delete permissions" : "Filer kan ikke deles med slettetilladelser",
+    "Files can't be shared with create permissions" : "Filer kan ikke deles med opret-tilladelser",
+    "Expiration date is in the past" : "Udløbsdatoen ligger tilbage i tid",
+    "Cannot set expiration date more than %s days in the future" : "Udløbsdato kan ikke sættes mere end %s dage ud i fremtiden",
     "Could not find category \"%s\"" : "Kunne ikke finde kategorien \"%s\"",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Det er kun tilladt at benytte følgene karakterer i et brugernavn \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Kun følgende tegn er tilladt, i et brugernavn: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"",
     "A valid username must be provided" : "Et gyldigt brugernavn skal angives",
+    "Username contains whitespace at the beginning or at the end" : "Brugernavn indeholder blanke tegn i begyndelsen eller slutningen",
     "A valid password must be provided" : "En gyldig adgangskode skal angives",
     "The username is already being used" : "Brugernavnet er allerede i brug",
+    "Login canceled by app" : "Log ind er annulleret af app",
+    "User disabled" : "Bruger deaktiveret",
+    "Help" : "Hjælp",
+    "Settings" : "Indstillinger",
+    "Users" : "Brugere",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "App'en \"%s\" kan ikke installeres, da følgende krav ikke er opfyldt: %s ",
+    "web services under your control" : "Webtjenester under din kontrol",
+    "File is currently busy, please try again later" : "Filen er i øjeblikket optaget - forsøg igen senere",
+    "Can't read file" : "Kan ikke læse filen",
+    "Application is not enabled" : "Programmet er ikke aktiveret",
+    "Authentication error" : "Adgangsfejl",
+    "Token expired. Please reload page." : "Adgang er udløbet. Genindlæs siden.",
+    "Unknown user" : "Ukendt bruger",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Ingen database driver (sqlite, mysql eller postgresql) er installeret.",
-    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Rettigheder kan som regel rettes ved %sat give webserveren skriveadgang til rodmappen%s.",
     "Cannot write into \"config\" directory" : "Kan ikke skrive til mappen \"config\"",
     "Cannot write into \"apps\" directory" : "Kan ikke skrive til mappen \"apps\"",
     "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Dette kan som regel rettes ved at %sgive webserveren skriveadgang til apps-mappen%s eller slå appstore fra i config-filen.",
-    "Cannot create \"data\" directory (%s)" : "Kan ikke oprette mappen \"data\" (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Dette kan som regel rettes ved <a href=\"%s\" target=\"_blank\">give webserveren skriveadgang til rodmappen</a>.",
+    "Cannot create \"data\" directory" : "Kunne ikke oprette mappen \"data\"",
+    "This can usually be fixed by <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">giving the webserver write access to the root directory</a>." : "Dette kan normalt blive ordnet ved at <a href=\"%s\" target=\"_blank\" rel=\"noreferrer\">give webserveren skrive-adgang til rodmappen</a>.",
+    "Permissions can usually be fixed by %sgiving the webserver write access to the root directory%s." : "Rettigheder kan som regel rettes ved %sat give webserveren skriveadgang til rodmappen%s.",
     "Setting locale to %s failed" : "Angivelse af %s for lokalitet mislykkedes",
     "Please install one of these locales on your system and restart your webserver." : "Installér venligst én af disse lokaliteter på dit system, og genstart din webserver.",
     "Please ask your server administrator to install the module." : "Du bedes anmode din serveradministrator om at installere modulet.",
     "PHP module %s not installed." : "PHP-modulet %s er ikke installeret.",
-    "Please ask your server administrator to update PHP to the latest version. Your PHP version is no longer supported by ownCloud and the PHP community." : "Bed venligst din serveradministrator om at opdatere PHP til seneste version. Din PHP-version understøttes ikke længere af ownCload og PHP-fællesskabet.",
-    "PHP is configured to populate raw post data. Since PHP 5.6 this will lead to PHP throwing notices for perfectly valid code." : "PHP er konfigureret til at udfylde rå postdata. Siden PHP 5.6 har dette ført til, at PHP smider med notitser for fuldstændig gyldig kode.",
-    "To fix this issue set <code>always_populate_raw_post_data</code> to <code>-1</code> in your php.ini" : "For at rette dette problem, så angiv <code>always_populate_raw_post_data</code> til <code>-1</code> i din php.ini",
-    "PHP is apparently setup to strip inline doc blocks. This will make several core apps inaccessible." : "PHP opsætning blokere \"inline doc blocks\". dette gør at flere grundlæggende apps utilgængelige",
+    "PHP setting \"%s\" is not set to \"%s\"." : "PHP-indstillingen \"%s\" er ikke angivet til \"%s\".",
+    "Adjusting this setting in php.ini will make ownCloud run again" : "Justeres denne indstilling i php.ini, så vil ownCloud kunne køre igen",
+    "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload er angivet til \"%s\", i stedet for den forventede værdi \"0\"",
+    "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "For at rette dette problem, angiv\n<code>mbstring.func_overload</code> til <code>0</code> i din php.ini",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 er mindst påkrævet. I øjeblikket er %s installeret.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Løs dette problem ved at opdatere din libxml2 version, og genstarte din webserver.",
+    "PHP is apparently set up to strip inline doc blocks. This will make several core apps inaccessible." : "PHP er tilsyneladende sat op til at fjerne indlejrede doc-blokke. Dette vil gøre adskillige kerneprogrammer utilgængelige.",
     "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Dette er sansynligvis forårsaget af et accelerator eller cache som Zend OPcache eller eAccelerator",
-    "PHP modules have been installed, but they are still listed as missing?" : "Der er installeret PHP-moduler, men de fremgår stadig som fraværende?",
+    "PHP modules have been installed, but they are still listed as missing?" : "Der er installeret PHP-moduler, men de fremstår stadig som fraværende?",
     "Please ask your server administrator to restart the web server." : "Du bedes anmode din serveradministrator om at genstarte webserveren.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 kræves",
     "Please upgrade your database version" : "Opgradér venligst din databaseversion",
-    "Error occurred while checking PostgreSQL version" : "Der opstod fejl under tjek af PostgreSQL-versionen",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Sørg venligst for at du har PostgreSQL >= 9 eller tjek loggen for flere informationer om fejlen",
     "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Tilpas venligst rettigheder til 0770, så mappen ikke fremvises for andre brugere.",
-    "Data directory (%s) is readable by other users" : "Datamappen (%s) kan læses af andre brugere",
-    "Data directory (%s) is invalid" : "Datamappen (%s) er ugyldig",
+    "Your Data directory is readable by other users" : "Din Data mappe er læselig af andre brugere",
+    "Your Data directory must be an absolute path" : "Datamappen skal have en absolut sti",
+    "Check the value of \"datadirectory\" in your configuration" : "Tjek værdien for \"databibliotek\" i din konfiguration",
+    "Your Data directory  is invalid" : "Din Data mappe er invalid",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Tjek venligst at datamappen indeholder en fil, \".ocdata\" i dens rod.",
-    "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Kunne ikke opnå en låsetype %d på \"%s\".",
+    "Storage unauthorized. %s" : "Lager uautoriseret. %s",
+    "Storage incomplete configuration. %s" : "Ufærdig lagerkonfiguration. %s",
+    "Storage connection error. %s" : "Lager tilslutningsfejl. %s",
+    "Storage is temporarily not available" : "Lagerplads er ikke tilgængelig lige nu",
+    "Storage connection timeout. %s" : "Lager tilslutningstidsudløb. %s",
+    "Help & Tips" : "Hjælp % Tips",
+    "A safe home for all your data" : "Et sikkert sted til dine data",
+    "User Authentication" : "Brugerautorisation",
+    "Workflows & Tags" : "Arbejdsflow & Tags"
 },
 "nplurals=2; plural=(n != 1);");
