@@ -8,6 +8,7 @@ OC.L10N.register(
     "Sample configuration detected" : "Esimerkkimääritykset havaittu",
     "PHP %s or higher is required." : "PHP %s tai sitä uudempi vaaditaan.",
     "PHP with a version lower than %s is required." : "PHP versiota %s alempi tarvitaan.",
+    "%sbit or higher PHP required." : "%s-bit tai korkeampi PHP vaaditaan.",
     "Following databases are supported: %s" : "Seuraavat tietokannat ovat tuettuja: %s",
     "The command line tool %s could not be found" : "Komentorivityökalua %s ei löytynyt",
     "The library %s is not available." : "Kirjastoa %s ei ole käytettävissä.",
@@ -16,16 +17,9 @@ OC.L10N.register(
     "Following platforms are supported: %s" : "Seuraavat alustat ovat tuettuja: %s",
     "ownCloud %s or higher is required." : "ownCloud %s tai uudempi vaaditaan.",
     "ownCloud %s or lower is required." : "ownCloud %s tai aiempi vaaditaan.",
-    "Help" : "Ohje",
-    "Personal" : "Henkilökohtainen",
-    "Users" : "Käyttäjät",
-    "Admin" : "Ylläpito",
-    "Recommended" : "Suositeltu",
-    "App \"%s\" cannot be installed because it is not compatible with this version of ownCloud." : "Sovelluksen \"%s\" asennus ei onnistu, koska se ei ole yhteensopiva tämän ownCloud-version kanssa.",
-    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Sovelluksen \"%s\" asennus ei onnistu, koska seuraavia riippuvuuksia ei ole täytetty: %s",
-    "No app name specified" : "Sovelluksen nimeä ei määritelty",
     "Unknown filetype" : "Tuntematon tiedostotyyppi",
     "Invalid image" : "Virheellinen kuva",
+    "Avatar image is not square" : "Avatar-kuva ei ole neliö",
     "today" : "tänään",
     "yesterday" : "eilen",
     "_%n day ago_::_%n days ago_" : ["%n päivä sitten","%n päivää sitten"],
@@ -36,15 +30,18 @@ OC.L10N.register(
     "_%n hour ago_::_%n hours ago_" : ["%n tunti sitten","%n tuntia sitten"],
     "_%n minute ago_::_%n minutes ago_" : ["%n minuutti sitten","%n minuuttia sitten"],
     "seconds ago" : "sekuntia sitten",
-    "web services under your control" : "verkkopalvelut hallinnassasi",
     "Module with id: %s does not exist. Please enable it in your apps settings or contact your administrator." : "Moduulia tunnisteella %s ei ole olemassa. Ota se käyttöön sovellusasetuksista tai ota yhteys ylläpitoon.",
+    "Builtin" : "Sisäänrakennettu",
+    "None" : "Ei mitään",
+    "Username and password" : "Käyttäjätunnus ja salasana",
+    "Username" : "Käyttäjätunnus",
+    "Password" : "Salasana",
+    "Log-in credentials, save in session" : "Kirjautumistiedot, tallenna istuntoon",
     "Empty filename is not allowed" : "Tiedostonimi ei voi olla tyhjä",
     "Dot files are not allowed" : "Pistetiedostot eivät ole sallittuja",
     "4-byte characters are not supported in file names" : "4 tavun merkit eivät ole tuettuja tiedostojen nimissä",
     "File name contains at least one invalid character" : "Tiedoston nimi sisältää ainakin yhden virheellisen merkin",
     "File name is too long" : "Tiedoston nimi on liian pitkä",
-    "File is currently busy, please try again later" : "Tiedosto on parhaillaan käytössä, yritä myöhemmin uudelleen",
-    "Can't read file" : "Tiedostoa ei voi lukea",
     "App directory already exists" : "Sovelluskansio on jo olemassa",
     "Can't create app folder. Please fix permissions. %s" : "Sovelluskansion luominen ei onnistu. Korjaa käyttöoikeudet. %s",
     "Archive does not contain a directory named %s" : "Arkisto ei sisällä kansiota nimeltä %s",
@@ -54,13 +51,19 @@ OC.L10N.register(
     "Archives of type %s are not supported" : "Tyypin %s arkistot eivät ole tuettuja",
     "Failed to open archive when installing app" : "Pakettitiedoston avaaminen epäonnistui sovellusta asennettaessa",
     "App does not provide an info.xml file" : "Sovellus ei sisällä info.xml-tiedostoa",
+    "App cannot be installed because appinfo file cannot be read." : "Sovellusta ei voi asentaa, koska appinfo-tiedostoa ei voi lukea.",
+    "Signature could not get checked. Please contact the app developer and check your admin screen." : "Allekirjoituksen tarkistaminen ei onnistunut. Ota yhteys sovelluskehittäjään ja tarkista ylläpitonäkymä.",
     "App can't be installed because of not allowed code in the App" : "Sovellusta ei voi asentaa, koska sovellus sisältää kiellettyä koodia",
     "App can't be installed because it is not compatible with this version of ownCloud" : "Sovellusta ei voi asentaa, koska se ei ole yhteensopiva käytössä olevan ownCloud-version kanssa",
-    "App can't be installed because the version in info.xml/version is not the same as the version reported from the app store" : "Sovellusta ei voi asentaa, koska info.xml/version ilmoittaa versioksi eri arvon kuin sovelluskauppa",
-    "Application is not enabled" : "Sovellusta ei ole otettu käyttöön",
-    "Authentication error" : "Tunnistautumisvirhe",
-    "Token expired. Please reload page." : "Valtuutus vanheni. Lataa sivu uudelleen.",
-    "Unknown user" : "Tuntematon käyttäjä",
+    "App can't be installed because the version in info.xml is not the same as the version reported from the app store" : "Sovelluksen asennus ei onnistu, koska sen info.xml:ssä ilmoitettu versio ei ole sama kuin sovelluskaupassa ilmoitettu versio",
+    "Apps" : "Sovellukset",
+    "General" : "Yleiset",
+    "Storage" : "Tallennustila",
+    "Security" : "Tietoturva",
+    "Encryption" : "Salaus",
+    "Sharing" : "Jakaminen",
+    "Search" : "Etsi",
+    "Updates" : "Päivitykset",
     "%s enter the database username." : "%s anna tietokannan käyttäjätunnus.",
     "%s enter the database name." : "%s anna tietokannan nimi.",
     "%s you may not use dots in the database name" : "%s et voi käyttää pisteitä tietokannan nimessä",
@@ -76,10 +79,11 @@ OC.L10N.register(
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Poista open_basedir-asetus php.ini-tiedostosta tai vaihda 64-bittiseen PHP:hen.",
     "Set an admin username." : "Aseta ylläpitäjän käyttäjätunnus.",
     "Set an admin password." : "Aseta ylläpitäjän salasana.",
+    "Invalid Federated Cloud ID" : "Virheellinen federoidun pilven tunniste",
     "%s shared »%s« with you" : "%s jakoi kohteen »%s« kanssasi",
     "Sharing %s failed, because the file does not exist" : "Kohteen %s jakaminen epäonnistui, koska tiedostoa ei ole olemassa",
     "You are not allowed to share %s" : "Oikeutesi eivät riitä kohteen %s jakamiseen.",
-    "Sharing %s failed, because the user %s is the item owner" : "Kohteen %s jakaminen epäonnistui, koska käyttäjä %s on kohteen omistaja",
+    "Sharing %s failed, because you can not share with yourself" : "Kohteen %s jakaminen epäonnistui, koska et voi jakaa itsesi kanssa",
     "Sharing %s failed, because the user %s does not exist" : "Kohteen %s jakaminen epäonnistui, koska käyttäjää %s ei ole olemassa",
     "Sharing %s failed, because this item is already shared with %s" : "Kohteen %s jakaminen epäonnistui, koska kohde on jo jaettu käyttäjän %s kanssa",
     "Sharing %s failed, because this item is already shared with user %s" : "Kohteen %s jakaminen epäonnistui, koska kohde on jo jaettu käyttäjän %s kanssa",
@@ -87,27 +91,44 @@ OC.L10N.register(
     "Sharing %s failed, because %s is not a member of the group %s" : "Kohteen %s jakaminen epäonnistui, koska käyttäjä %s ei ole ryhmän %s jäsen",
     "You need to provide a password to create a public link, only protected links are allowed" : "Anna salasana luodaksesi julkisen linkin. Vain suojatut linkit ovat sallittuja",
     "Sharing %s failed, because sharing with links is not allowed" : "Kohteen %s jakaminen epäonnistui, koska jakaminen linkkejä käyttäen ei ole sallittu",
+    "Not allowed to create a federated share with the same user" : "Saman käyttäjän kanssa ei ole sallittua luoda federoitua jakoa",
     "Sharing %s failed, could not find %s, maybe the server is currently unreachable." : "Kohteen %s jakaminen epäonnistui, kohdetta %s ei löytynyt. Kenties palvelin ei ole juuri nyt tavoitettavissa.",
     "Setting permissions for %s failed, because the item was not found" : "Kohteen %s oikeuksien asettaminen epäonnistui, koska kohdetta ei löytynyt",
     "Cannot set expiration date. Expiration date is in the past" : "Vanhentumispäivää ei voi asettaa. Vanhentumispäivä on jo mennyt",
     "Cannot clear expiration date. Shares are required to have an expiration date." : "Vanhenemispäivän tyhjentäminen ei onnistu. Jaoille on määritelty pakolliseksi vanhenemispäivä.",
     "Sharing backend %s not found" : "Jakamisen taustaosaa %s ei löytynyt",
     "Sharing backend for %s not found" : "Jakamisen taustaosaa kohteelle %s ei löytynyt",
-    "Sharing %s failed, because the user %s is the original sharer" : "Kohteen %s jakaminen epäonnistui, koska käyttäjä %s on alkuperäinen jakaja",
+    "Sharing failed, because the user %s is the original sharer" : "Jakaminen epäonnistui, koska käyttäjä %s ei ole alkuperäinen jakaja",
     "Sharing %s failed, because resharing is not allowed" : "Kohteen %s jakaminen epäonnistui, koska jakaminen uudelleen ei ole sallittu",
     "Sharing %s failed, because the file could not be found in the file cache" : "Kohteen %s jakaminen epäonnistui, koska tiedostoa ei löytynyt tiedostovälimuistista",
+    "Cannot increase permissions of %s" : "Kohteen %s käyttöoikeuksien lisääminen ei onnistu",
+    "Files can't be shared with delete permissions" : "Tiedostoja ei voi jakaa poistamisoikeuksin",
+    "Files can't be shared with create permissions" : "Tiedostoja ei voi jakaa luomisoikeuksin",
+    "Expiration date is in the past" : "Vanhenemispäivä on menneisyydessä",
+    "Cannot set expiration date more than %s days in the future" : "Vanhenemispäivä voi olla korkeintaan %s päivän päässä tulevaisuudessa",
     "Could not find category \"%s\"" : "Luokkaa \"%s\" ei löytynyt",
-    "Apps" : "Sovellukset",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-\"",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", and \"_.@-'\"" : "Vain seuraavat merkit ovat sallittuja käyttäjätunnuksessa: \"a-z\", \"A-Z\", \"0-9\" ja \"_.@-'\"",
     "A valid username must be provided" : "Anna kelvollinen käyttäjätunnus",
+    "Username contains whitespace at the beginning or at the end" : "Käyttäjätunnus sisältää tyhjätilaa joko alussa tai lopussa",
     "A valid password must be provided" : "Anna kelvollinen salasana",
     "The username is already being used" : "Käyttäjätunnus on jo käytössä",
+    "Login canceled by app" : "Kirjautuminen peruttiin sovelluksen toimesta",
+    "User disabled" : "Käyttäjä poistettu käytöstä",
+    "Help" : "Ohje",
+    "Settings" : "Asetukset",
+    "Users" : "Käyttäjät",
+    "App \"%s\" cannot be installed because the following dependencies are not fulfilled: %s" : "Sovelluksen \"%s\" asennus ei onnistu, koska seuraavia riippuvuuksia ei ole täytetty: %s",
+    "web services under your control" : "verkkopalvelut hallinnassasi",
+    "File is currently busy, please try again later" : "Tiedosto on parhaillaan käytössä, yritä myöhemmin uudelleen",
+    "Can't read file" : "Tiedostoa ei voi lukea",
+    "Application is not enabled" : "Sovellusta ei ole otettu käyttöön",
+    "Authentication error" : "Tunnistautumisvirhe",
+    "Token expired. Please reload page." : "Valtuutus vanheni. Lataa sivu uudelleen.",
+    "Unknown user" : "Tuntematon käyttäjä",
     "No database drivers (sqlite, mysql, or postgresql) installed." : "Tietokanta-ajureita (sqlite, mysql tai postgresql) ei ole asennettu.",
-    "Microsoft Windows Platform is not supported" : "Microsoft Windows -alusta ei ole tuettu",
     "Cannot write into \"config\" directory" : "Hakemistoon \"config\" kirjoittaminen ei onnistu",
     "Cannot write into \"apps\" directory" : "Hakemistoon \"apps\" kirjoittaminen ei onnistu",
-    "Cannot create \"data\" directory (%s)" : "Kansion \"data\" luominen ei onnistu (%s)",
-    "This can usually be fixed by <a href=\"%s\" target=\"_blank\">giving the webserver write access to the root directory</a>." : "Tämä on yleensä korjattavissa <a href=\"%s\" target=\"_blank\">antamalla http-palvelimelle kirjoitusoikeuden juurihakemistoon</a>.",
+    "This can usually be fixed by %sgiving the webserver write access to the apps directory%s or disabling the appstore in the config file." : "Tämä on yleensä mahdollista korjata %santamalla HTTP-palvelimelle kirjoitusoikeus sovellushakemistoon%s tai poistamalla sovelluskauppa pois käytöstä asetustiedostoa käyttäen.",
     "Setting locale to %s failed" : "Maa-asetuksen %s asettaminen epäonnistui",
     "Please install one of these locales on your system and restart your webserver." : "Asenna ainakin yksi kyseisistä maa-asetuksista järjestelmään ja käynnistä http-palvelin uudelleen.",
     "Please ask your server administrator to install the module." : "Pyydä palvelimen ylläpitäjää asentamaan moduulin.",
@@ -116,17 +137,24 @@ OC.L10N.register(
     "Adjusting this setting in php.ini will make ownCloud run again" : "Tämän asetuksen muuttaminen php.ini-tiedostossa saattaa ownCloudin jälleen toimintakykyiseksi",
     "mbstring.func_overload is set to \"%s\" instead of the expected value \"0\"" : "mbstring.func_overload on asetettu arvoon \"%s\" odotetun arvon \"0\" sijaan",
     "To fix this issue set <code>mbstring.func_overload</code> to <code>0</code> in your php.ini" : "Korjaa tämä ongelma asettamalla <code>mbstring.func_overload</code> arvoon <code>0</code> php.ini-tiedostossasi",
+    "libxml2 2.7.0 is at least required. Currently %s is installed." : "Vähintään libxml2 2.7.0 vaaditaan. %s on asennettu.",
+    "To fix this issue update your libxml2 version and restart your web server." : "Päivitä libxml2:n versio ja käynnistä http-palvelin uudelleen.",
+    "This is probably caused by a cache/accelerator such as Zend OPcache or eAccelerator." : "Tämä johtuu todennäköisesti välimuistista tai kiihdyttimestä kuten Zend OPcachesta tai eAcceleratorista.",
     "PHP modules have been installed, but they are still listed as missing?" : "PHP-moduulit on asennettu, mutta ovatko ne vieläkin listattu puuttuviksi?",
     "Please ask your server administrator to restart the web server." : "Pyydä palvelimen ylläpitäjää käynnistämään web-palvelin uudelleen.",
     "PostgreSQL >= 9 required" : "PostgreSQL >= 9 vaaditaan",
     "Please upgrade your database version" : "Päivitä tietokantasi versio",
-    "Error occurred while checking PostgreSQL version" : "Virhe PostgreSQL:n versiota tarkistaessa",
-    "Please make sure you have PostgreSQL >= 9 or check the logs for more information about the error" : "Varmista, että käytössäsi on PostgreSQL >= 9 tai tarkista lokit saadaksesi lisätietoja virheestä",
-    "Data directory (%s) is readable by other users" : "Datakansio (%s) on muiden käyttäjien luettavissa",
-    "Data directory (%s) must be an absolute path" : "Datahakemiston (%s) tulee olla absoluuttinen polku",
+    "Your Data directory is readable by other users" : "Datahakemistosi on muiden käyttäjien luettavissa",
+    "Your Data directory must be an absolute path" : "Datahakemistosi tulee olla absoluuttinen polku",
     "Check the value of \"datadirectory\" in your configuration" : "Tarkista \"datadirectory\"-arvo asetuksistasi",
-    "Data directory (%s) is invalid" : "Datakansio (%s) on virheellinen",
+    "Your Data directory  is invalid" : "Datahakemistosi on virheellinen",
     "Please check that the data directory contains a file \".ocdata\" in its root." : "Varmista, että datakansion juuressa on tiedosto \".ocdata\".",
-    "Could not obtain lock type %d on \"%s\"." : "Lukitustapaa %d ei saatu kohteelle \"%s\"."
+    "Could not obtain lock type %d on \"%s\"." : "Lukitustapaa %d ei saatu kohteelle \"%s\".",
+    "Storage unauthorized. %s" : "Tallennustila ei ole valtuutettu. %s",
+    "Storage incomplete configuration. %s" : "Tallennustilan puutteellinen määritys. %s",
+    "Storage connection error. %s" : "Tallennustilan yhteysvirhe. %s",
+    "Storage is temporarily not available" : "Tallennustila ei juuri nyt ole käytettävissä",
+    "Storage connection timeout. %s" : "Tallennustilan yhteyden aikakatkaisu. %s",
+    "A safe home for all your data" : "Turvallinen koti tiedoillesi"
 },
 "nplurals=2; plural=(n != 1);");
