@@ -2,10 +2,12 @@
 /**
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Björn Schießle <bjoern@schiessle.org>
- * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Joas Schilling <coding@schilljs.com>
  * @author Roeland Jago Douma <rullzer@owncloud.com>
+ * @author Thomas Müller <thomas.mueller@tmit.eu>
+ * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -42,6 +44,8 @@ use OCP\Share\Exceptions\GenericShareException;
 use OCP\Share\Exceptions\ShareNotFound;
 use OCP\Share\IManager;
 use OCP\Share\IProviderFactory;
+use Symfony\Component\EventDispatcher\EventDispatcher;
+use Symfony\Component\EventDispatcher\GenericEvent;
 
 /**
  * This class is the communication hub for all sharing related operations.
@@ -70,6 +74,8 @@ class Manager implements IManager {
 	private $rootFolder;
 	/** @var CappedMemoryCache */
 	private $sharingDisabledForUsersCache;
+	/** @var EventDispatcher  */
+	private $eventDispatcher;
 
 
 	/**
@@ -96,7 +102,8 @@ class Manager implements IManager {
 			IL10N $l,
 			IProviderFactory $factory,
 			IUserManager $userManager,
-			IRootFolder $rootFolder
+			IRootFolder $rootFolder,
+			EventDispatcher $eventDispatcher
 	) {
 		$this->logger = $logger;
 		$this->config = $config;
@@ -109,6 +116,24 @@ class Manager implements IManager {
 		$this->userManager = $userManager;
 		$this->rootFolder = $rootFolder;
 		$this->sharingDisabledForUsersCache = new CappedMemoryCache();
+		$this->eventDispatcher = $eventDispatcher;
+	}
+
+	/**
+	 * @param int[] $shareTypes - ref \OC\Share\Constants[]
+	 * @return int[] $providerIdMap e.g. { "ocinternal" => { 0, 1 }[2] }[1]
+	 */
+	private function shareTypeToProviderMap($shareTypes) {
+		$providerIdMap = [];
+		foreach ($shareTypes as $shareType) {
+			// Get provider and its ID, at this point provider is cached at IProviderFactory instance
+			$provider = $this->factory->getProviderForType($shareType);
+			$providerId = $provider->identifier();
+
+			// Create a key -> multi value map
+			$providerIdMap[$providerId][] = $shareType;
+		}
+		return $providerIdMap;
 	}
 
 	/**
@@ -128,15 +153,6 @@ class Manager implements IManager {
 	 * @throws \Exception
 	 */
 	protected function verifyPassword($password) {
-		if ($password === null) {
-			// No password is set, check if this is allowed.
-			if ($this->shareApiLinkEnforcePassword()) {
-				throw new \InvalidArgumentException('Passwords are enforced for link shares');
-			}
-
-			return;
-		}
-
 		// Let others verify the password
 		$accepted = true;
 		$message = '';
@@ -149,6 +165,28 @@ class Manager implements IManager {
 		if (!$accepted) {
 			throw new \Exception($message);
 		}
+
+		\OC::$server->getEventDispatcher()->dispatch(
+			'OCP\Share::validatePassword',
+			new GenericEvent(null, ['password' => $password])
+		);
+	}
+
+	/**
+	 * Check if a password must be enforced if the shared has those permissions
+	 * @param int $permissions \OCP\Constants::PERMISSION_* ("|" can be use for sets of permissions)
+	 * @return bool true if the password must be enforced, false otherwise
+	 */
+	protected function passwordMustBeEnforced($permissions) {
+		$roEnforcement = $permissions === \OCP\Constants::PERMISSION_READ && $this->shareApiLinkEnforcePasswordReadOnly();
+		$woEnforcement = $permissions === \OCP\Constants::PERMISSION_CREATE && $this->shareApiLinkEnforcePasswordWriteOnly();
+		// use read & write enforcement for the rest of the cases
+		$rwEnforcement = ($permissions !== \OCP\Constants::PERMISSION_READ && $permissions !== \OCP\Constants::PERMISSION_CREATE) && $this->shareApiLinkEnforcePasswordReadWrite();
+		if ($roEnforcement || $woEnforcement || $rwEnforcement) {
+			return true;
+		} else {
+			return false;
+		}
 	}
 
 	/**
@@ -242,11 +280,6 @@ class Manager implements IManager {
 			throw new GenericShareException($message_t, $message_t, 404);
 		}
 
-		// Check that read permissions are always set
-		if (($share->getPermissions() & \OCP\Constants::PERMISSION_READ) === 0) {
-			throw new \InvalidArgumentException('Shares need at least read permissions');
-		}
-
 		if ($share->getNode() instanceof \OCP\Files\File) {
 			if ($share->getPermissions() & \OCP\Constants::PERMISSION_DELETE) {
 				$message_t = $this->l->t('Files can\'t be shared with delete permissions');
@@ -401,7 +434,7 @@ class Manager implements IManager {
 		}
 
 		// Verify if the user can share with this group
-		if ($this->shareWithGroupMembersOnly()) {
+		if ($this->shareWithMembershipGroupOnly()) {
 			$sharedBy = $this->userManager->get($share->getSharedBy());
 			$sharedWith = $this->groupManager->get($share->getSharedWith());
 			if (is_null($sharedWith) || !$sharedWith->inGroup($sharedBy)) {
@@ -565,7 +598,11 @@ class Manager implements IManager {
 			$this->validateExpirationDate($share);
 
 			//Verify the password
-			$this->verifyPassword($share->getPassword());
+			if ($this->passwordMustBeEnforced($share->getPermissions()) && $share->getPassword() === null) {
+				throw new \InvalidArgumentException('Passwords are enforced for link shares');
+			} else {
+				$this->verifyPassword($share->getPassword());
+			}
 
 			// If a password is set. Hash it!
 			if ($share->getPassword() !== null) {
@@ -603,6 +640,9 @@ class Manager implements IManager {
 		];
 		\OC_Hook::emit('OCP\Share', 'pre_shared', $preHookData);
 
+		$beforeEvent = new GenericEvent(null, ['shareData' => $preHookData]);
+		$this->eventDispatcher->dispatch('share.beforeCreate', $beforeEvent);
+
 		if ($run === false) {
 			throw new \Exception($error);
 		}
@@ -624,10 +664,14 @@ class Manager implements IManager {
 			'shareWith' => $share->getSharedWith(),
 			'itemTarget' => $share->getTarget(),
 			'fileTarget' => $share->getTarget(),
+			'passwordEnabled' => (!is_null($share->getPassword()) and ($share->getPassword() !== '')),
 		];
 
 		\OC_Hook::emit('OCP\Share', 'post_shared', $postHookData);
 
+		$afterEvent = new GenericEvent(null, ['shareData' => $postHookData, 'shareObject' => $share, 'result' => 'success']);
+		$this->eventDispatcher->dispatch('share.afterCreate', $afterEvent);
+
 		return $share;
 	}
 
@@ -676,9 +720,14 @@ class Manager implements IManager {
 			$this->linkCreateChecks($share);
 
 			// Password updated.
-			if ($share->getPassword() !== $originalShare->getPassword()) {
+			if ($share->getPassword() !== $originalShare->getPassword() ||
+					$share->getPermissions() !== $originalShare->getPermissions()) {
 				//Verify the password
-				$this->verifyPassword($share->getPassword());
+				if ($this->passwordMustBeEnforced($share->getPermissions()) && $share->getPassword() === null) {
+					throw new \InvalidArgumentException('Passwords are enforced for link shares');
+				} else {
+					$this->verifyPassword($share->getPassword(), $share->getPermissions());
+				}
 
 				// If a password is set. Hash it!
 				if ($share->getPassword() !== null) {
@@ -686,9 +735,10 @@ class Manager implements IManager {
 				}
 			}
 
+			//Verify the expiration date
+			$this->validateExpirationDate($share);
+
 			if ($share->getExpirationDate() != $originalShare->getExpirationDate()) {
-				//Verify the expiration date
-				$this->validateExpirationDate($share);
 				$expirationDateUpdated = true;
 			}
 		}
@@ -699,6 +749,9 @@ class Manager implements IManager {
 		$provider = $this->factory->getProviderForType($share->getShareType());
 		$share = $provider->update($share);
 
+		$shareAfterUpdateEvent = new GenericEvent(null);
+		$shareAfterUpdateEvent->setArgument('shareobject', $share);
+		$update = false;
 		if ($expirationDateUpdated === true) {
 			\OC_Hook::emit('OCP\Share', 'post_set_expiration_date', [
 				'itemType' => $share->getNode() instanceof \OCP\Files\File ? 'file' : 'folder',
@@ -706,6 +759,9 @@ class Manager implements IManager {
 				'date' => $share->getExpirationDate(),
 				'uidOwner' => $share->getSharedBy(),
 			]);
+			$shareAfterUpdateEvent->setArgument('expirationdateupdated', true);
+			$shareAfterUpdateEvent->setArgument('oldexpirationdate', $originalShare->getExpirationDate());
+			$update = true;
 		}
 
 		if ($share->getPassword() !== $originalShare->getPassword()) {
@@ -716,6 +772,8 @@ class Manager implements IManager {
 				'token' => $share->getToken(),
 				'disabled' => is_null($share->getPassword()),
 			]);
+			$shareAfterUpdateEvent->setArgument('passwordupdate', true);
+			$update = true;
 		}
 
 		if ($share->getPermissions() !== $originalShare->getPermissions()) {
@@ -724,7 +782,7 @@ class Manager implements IManager {
 			} else {
 				$userFolder = $this->rootFolder->getUserFolder($share->getSharedBy());
 			}
-			\OC_Hook::emit('OCP\Share', 'post_update_permissions', array(
+			\OC_Hook::emit('OCP\Share', 'post_update_permissions', [
 				'itemType' => $share->getNode() instanceof \OCP\Files\File ? 'file' : 'folder',
 				'itemSource' => $share->getNode()->getId(),
 				'shareType' => $share->getShareType(),
@@ -732,9 +790,16 @@ class Manager implements IManager {
 				'uidOwner' => $share->getSharedBy(),
 				'permissions' => $share->getPermissions(),
 				'path' => $userFolder->getRelativePath($share->getNode()->getPath()),
-			));
+			]);
+			$shareAfterUpdateEvent->setArgument('permissionupdate', true);
+			$shareAfterUpdateEvent->setArgument('oldpermissions', $originalShare->getPermissions());
+			$shareAfterUpdateEvent->setArgument('path', $userFolder->getRelativePath($share->getNode()->getPath()));
+			$update = true;
 		}
 
+		if ($update === true) {
+			$this->eventDispatcher->dispatch('share.afterupdate', $shareAfterUpdateEvent);
+		}
 		return $share;
 	}
 
@@ -807,6 +872,8 @@ class Manager implements IManager {
 		// Emit pre-hook
 		\OC_Hook::emit('OCP\Share', 'pre_unshare', $hookParams);
 
+		$beforeEvent = new GenericEvent(null, ['share' => $hookParams, 'shareObject' => $share]);
+		$this->eventDispatcher->dispatch('share.beforeDelete', $beforeEvent);
 		// Get all children and delete them as well
 		$deletedShares = $this->deleteChildren($share);
 
@@ -824,6 +891,8 @@ class Manager implements IManager {
 
 		// Emit post hook
 		\OC_Hook::emit('OCP\Share', 'post_unshare', $hookParams);
+		$afterEvent = new GenericEvent(null, ['share' => $hookParams['deletedShares']]);
+		$this->eventDispatcher->dispatch('share.afterDelete', $afterEvent);
 	}
 
 
@@ -850,6 +919,13 @@ class Manager implements IManager {
 		$hookParams['itemTarget'] = $hookParams['fileTarget'];
 		$hookParams['unsharedItems'] = [$hookParams];
 		\OC_Hook::emit('OCP\Share', 'post_unshareFromSelf', $hookParams);
+		$event = new GenericEvent(null, [
+			'shareRecipient' => $recipientId,
+			'shareOwner' => $share->getSharedBy(),
+			'recipientPath' => $share->getTarget(),
+			'ownerPath' => $share->getNode()->getPath(),
+			'nodeType' => $share->getNodeType()]);
+		\OC::$server->getEventDispatcher()->dispatch('fromself.unshare',$event);
 	}
 
 	/**
@@ -881,6 +957,43 @@ class Manager implements IManager {
 		$provider->move($share, $recipientId);
 	}
 
+	/**
+	 * @inheritdoc
+	 */
+	public function getAllSharesBy($userId, $shareTypes, $nodeIDs, $reshares = false) {
+		// This function requires at least 1 node (parent folder)
+		if (empty($nodeIDs)) {
+			throw new \InvalidArgumentException('Array of nodeIDs empty');
+		}
+		// This will ensure that if there are multiple share providers for the same share type, we will execute it in batches
+		$shares = array();
+
+		$providerIdMap = $this->shareTypeToProviderMap($shareTypes);
+
+		$today = new \DateTime();
+		foreach ($providerIdMap as $providerId => $shareTypeArray) {
+			// Get provider from cache
+			$provider = $this->factory->getProvider($providerId);
+
+			$queriedShares = $provider->getAllSharesBy($userId, $shareTypeArray, $nodeIDs, $reshares);
+			foreach ($queriedShares as $queriedShare){
+				if ($queriedShare->getShareType() === \OCP\Share::SHARE_TYPE_LINK && $queriedShare->getExpirationDate() !== null &&
+					$queriedShare->getExpirationDate() <= $today
+				) {
+					try {
+						$this->deleteShare($queriedShare);
+					} catch (NotFoundException $e) {
+						//Ignore since this basically means the share is deleted
+					}
+					continue;
+				}
+				array_push($shares, $queriedShare);
+			}
+		}
+
+		return $shares;
+	}
+
 	/**
 	 * @inheritdoc
 	 */
@@ -960,6 +1073,27 @@ class Manager implements IManager {
 		return $provider->getSharedWith($userId, $shareType, $node, $limit, $offset);
 	}
 
+
+	/**
+	 * @inheritdoc
+	 */
+	public function getAllSharedWith($userId, $shareTypes, $node = null) {
+		$shares = [];
+		
+		// Aggregate all required $shareTypes by mapping provider to supported shareTypes
+		$providerIdMap = $this->shareTypeToProviderMap($shareTypes);
+		foreach ($providerIdMap as $providerId => $shareTypeArray) {
+			// Get provider from cache
+			$provider = $this->factory->getProvider($providerId);
+			
+			// Obtain all shares for all the supported provider types
+			$queriedShares = $provider->getAllSharedWith($userId, $node);
+			$shares = array_merge($shares, $queriedShares);
+		}
+
+		return $shares;
+	}
+	
 	/**
 	 * @inheritdoc
 	 */
@@ -994,6 +1128,21 @@ class Manager implements IManager {
 	 * @return Share[]
 	 */
 	public function getSharesByPath(\OCP\Files\Node $path, $page=0, $perPage=50) {
+		$types = [\OCP\Share::SHARE_TYPE_USER, \OCP\Share::SHARE_TYPE_GROUP];
+		$providers = [];
+		$results = [];
+
+		foreach ($types as $type) {
+			$provider = $this->factory->getProviderForType($type);
+			// store this way to deduplicate entries by id
+			$providers[$provider->identifier()] = $provider;
+		}
+
+		foreach ($providers as $provider) {
+			$results = array_merge($results, $provider->getSharesByPath($path));
+		}
+
+		return $results;
 	}
 
 	/**
@@ -1149,12 +1298,39 @@ class Manager implements IManager {
 	}
 
 	/**
-	 * Is password on public link requires
+	 * Is password on public link requires (fallback to shareApiLinkEnforcePasswordReadOnly)
 	 *
 	 * @return bool
 	 */
 	public function shareApiLinkEnforcePassword() {
-		return $this->config->getAppValue('core', 'shareapi_enforce_links_password', 'no') === 'yes';
+		return $this->shareApiLinkEnforcePasswordReadOnly();
+	}
+
+	/**
+	 * Is password enforced for read-only shares?
+	 *
+	 * @return bool
+	 */
+	public function shareApiLinkEnforcePasswordReadOnly() {
+		return $this->config->getAppValue('core', 'shareapi_enforce_links_password_read_only', 'no') === 'yes';
+	}
+
+	/**
+	 * Is password enforced for read & write shares?
+	 *
+	 * @return bool
+	 */
+	public function shareApiLinkEnforcePasswordReadWrite() {
+		return $this->config->getAppValue('core', 'shareapi_enforce_links_password_read_write', 'no') === 'yes';
+	}
+
+	/**
+	 * Is password enforced for write-only shares?
+	 *
+	 * @return bool
+	 */
+	public function shareApiLinkEnforcePasswordWriteOnly() {
+		return $this->config->getAppValue('core', 'shareapi_enforce_links_password_write_only', 'no') === 'yes';
 	}
 
 	/**
@@ -1202,6 +1378,14 @@ class Manager implements IManager {
 		return $this->config->getAppValue('core', 'shareapi_only_share_with_group_members', 'no') === 'yes';
 	}
 
+	/**
+	 * check if user can only share with groups he's member of
+	 * @return bool
+	 */
+	public function shareWithMembershipGroupOnly() {
+		return $this->config->getAppValue('core', 'shareapi_only_share_with_membership_groups', 'no') === 'yes';
+	}
+
 	/**
 	 * Check if users can share with groups
 	 * @return bool
