@@ -3,15 +3,17 @@
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Bernhard Posselt <dev@bernhard-posselt.com>
  * @author Christoph Wurst <christoph@owncloud.com>
+ * @author Felix Rupp <github@felixrupp.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Morris Jobke <hey@morrisjobke.de>
  * @author Robin Appelman <icewind@owncloud.com>
  * @author Robin McCorkell <robin@mccorkell.me.uk>
+ * @author Semih Serhat Karakaya <karakayasemi@itu.edu.tr>
  * @author Thomas Müller <thomas.mueller@tmit.eu>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -38,22 +40,29 @@ use OC\Authentication\Exceptions\PasswordLoginForbiddenException;
 use OC\Authentication\Token\IProvider;
 use OC\Authentication\Token\IToken;
 use OC\Hooks\Emitter;
-use OC_App;
+use OC\Hooks\PublicEmitter;
 use OC_User;
 use OC_Util;
 use OCA\DAV\Connector\Sabre\Auth;
-use OCP\App\IAppManager;
-use OCP\AppFramework\QueryException;
+use OCP\App\IServiceLoader;
 use OCP\AppFramework\Utility\ITimeFactory;
+use OCP\Authentication\IApacheBackend;
 use OCP\Authentication\IAuthModule;
+use OCP\Events\EventEmitterTrait;
+use OCP\Files\NoReadAccessException;
+use OCP\Files\NotPermittedException;
 use OCP\IConfig;
+use OCP\ILogger;
 use OCP\IRequest;
 use OCP\ISession;
 use OCP\IUser;
+use OCP\IUserBackend;
 use OCP\IUserManager;
 use OCP\IUserSession;
 use OCP\Session\Exceptions\SessionNotAvailableException;
+use OCP\UserInterface;
 use OCP\Util;
+use Symfony\Component\EventDispatcher\GenericEvent;
 
 /**
  * Class Session
@@ -67,22 +76,25 @@ use OCP\Util;
  * - postCreateUser(\OC\User\User $user)
  * - preLogin(string $user, string $password)
  * - postLogin(\OC\User\User $user, string $password)
+ * - failedLogin(string $user)
  * - preRememberedLogin(string $uid)
  * - postRememberedLogin(\OC\User\User $user)
  * - logout()
+ * - postLogout()
  *
  * @package OC\User
  */
 class Session implements IUserSession, Emitter {
 
-	/** @var IUserManager $manager */
+	use EventEmitterTrait;
+	/** @var IUserManager | PublicEmitter $manager */
 	private $manager;
 
 	/** @var ISession $session */
 	private $session;
 
 	/** @var ITimeFactory */
-	private $timeFacory;
+	private $timeFactory;
 
 	/** @var IProvider */
 	private $tokenProvider;
@@ -90,22 +102,40 @@ class Session implements IUserSession, Emitter {
 	/** @var IConfig */
 	private $config;
 
+	/** @var ILogger */
+	private $logger;
+
 	/** @var User $activeUser */
 	protected $activeUser;
 
+	/** @var IServiceLoader */
+	private $serviceLoader;
+
+	/** @var SyncService */
+	protected $userSyncService;
+
 	/**
 	 * @param IUserManager $manager
 	 * @param ISession $session
-	 * @param ITimeFactory $timeFacory
+	 * @param ITimeFactory $timeFactory
 	 * @param IProvider $tokenProvider
 	 * @param IConfig $config
+	 * @param ILogger $logger
+	 * @param IServiceLoader $serviceLoader
+	 * @param SyncService $userSyncService
 	 */
-	public function __construct(IUserManager $manager, ISession $session, ITimeFactory $timeFacory, $tokenProvider, IConfig $config) {
+	public function __construct(IUserManager $manager, ISession $session,
+								ITimeFactory $timeFactory, IProvider $tokenProvider,
+								IConfig $config, ILogger $logger, IServiceLoader $serviceLoader,
+								SyncService $userSyncService) {
 		$this->manager = $manager;
 		$this->session = $session;
-		$this->timeFacory = $timeFacory;
+		$this->timeFactory = $timeFactory;
 		$this->tokenProvider = $tokenProvider;
 		$this->config = $config;
+		$this->logger = $logger;
+		$this->serviceLoader = $serviceLoader;
+		$this->userSyncService = $userSyncService;
 	}
 
 	/**
@@ -133,15 +163,6 @@ class Session implements IUserSession, Emitter {
 		$this->manager->removeListener($scope, $method, $callback);
 	}
 
-	/**
-	 * get the manager object
-	 *
-	 * @return Manager
-	 */
-	public function getManager() {
-		return $this->manager;
-	}
-
 	/**
 	 * get the session object
 	 *
@@ -167,7 +188,7 @@ class Session implements IUserSession, Emitter {
 	/**
 	 * set the currently active user
 	 *
-	 * @param User|null $user
+	 * @param IUser|null $user
 	 */
 	public function setUser($user) {
 		if (is_null($user)) {
@@ -198,7 +219,6 @@ class Session implements IUserSession, Emitter {
 			if (is_null($this->activeUser)) {
 				return null;
 			}
-			$this->validateSession();
 		}
 		return $this->activeUser;
 	}
@@ -209,7 +229,11 @@ class Session implements IUserSession, Emitter {
 	 * - For token-authenticated clients, the token validity is checked
 	 * - For browsers, the session token validity is checked
 	 */
-	protected function validateSession() {
+	public function validateSession() {
+		if (!$this->getUser()) {
+			return;
+		}
+
 		$token = null;
 		$appPassword = $this->session->get('app_password');
 
@@ -264,15 +288,15 @@ class Session implements IUserSession, Emitter {
 	public function getLoginName() {
 		if ($this->activeUser) {
 			return $this->session->get('loginname');
-		} else {
-			$uid = $this->session->get('user_id');
-			if ($uid) {
-				$this->activeUser = $this->manager->get($uid);
-				return $this->session->get('loginname');
-			} else {
-				return null;
-			}
 		}
+
+		$uid = $this->session->get('user_id');
+		if ($uid) {
+			$this->activeUser = $this->manager->get($uid);
+			return $this->session->get('loginname');
+		}
+
+		return null;
 	}
 
 	/**
@@ -288,10 +312,8 @@ class Session implements IUserSession, Emitter {
 
 		if ($this->validateToken($password, $uid)) {
 			return $this->loginWithToken($password);
-		} else {
-			return $this->loginWithPassword($uid, $password);
 		}
-		return false;
+		return $this->loginWithPassword($uid, $password);
 	}
 
 	/**
@@ -303,12 +325,16 @@ class Session implements IUserSession, Emitter {
 	 * @param string $user
 	 * @param string $password
 	 * @param IRequest $request
+	 * @throws \InvalidArgumentException
 	 * @throws LoginException
 	 * @throws PasswordLoginForbiddenException
 	 * @return boolean
 	 */
 	public function logClientIn($user, $password, IRequest $request) {
 		$isTokenPassword = $this->isTokenPassword($password);
+		if ($user === null || trim($user) === '') {
+			throw new \InvalidArgumentException('$user cannot be empty');
+		}
 		if (!$isTokenPassword && $this->isTokenAuthEnforced()) {
 			throw new PasswordLoginForbiddenException();
 		}
@@ -337,7 +363,7 @@ class Session implements IUserSession, Emitter {
 		if (!is_null($request->getCookie('cookie_test'))) {
 			return true;
 		}
-		setcookie('cookie_test', 'test', $this->timeFacory->getTime() + 3600);
+		setcookie('cookie_test', 'test', $this->timeFactory->getTime() + 3600);
 		return false;
 	}
 
@@ -349,7 +375,7 @@ class Session implements IUserSession, Emitter {
 		Util::emitHook(
 			'\OCA\Files_Sharing\API\Server2Server',
 			'preLoginNameUsedAsUserName',
-			array('uid' => &$username)
+			['uid' => &$username]
 		);
 		$user = $this->manager->get($username);
 		if (is_null($user)) {
@@ -381,15 +407,45 @@ class Session implements IUserSession, Emitter {
 		}
 	}
 
-	protected function prepareUserLogin() {
+	/**
+	 * Unintentional public
+	 *
+	 * @param bool $firstTimeLogin
+	 */
+	public function prepareUserLogin($firstTimeLogin = false) {
 		// TODO: mock/inject/use non-static
 		// Refresh the token
 		\OC::$server->getCsrfTokenManager()->refreshToken();
 		//we need to pass the user name, which may differ from login name
 		$user = $this->getUser()->getUID();
 		OC_Util::setupFS($user);
-		//trigger creation of user home and /files folder
-		\OC::$server->getUserFolder($user);
+
+		if ($firstTimeLogin) {
+			// TODO: lock necessary?
+			//trigger creation of user home and /files folder
+			$userFolder = \OC::$server->getUserFolder($user);
+
+			try {
+				// copy skeleton
+				\OC_Util::copySkeleton($user, $userFolder);
+			} catch (NotPermittedException $ex) {
+				// possible if files directory is in an readonly jail
+				$this->logger->warning(
+					'Skeleton not created due to missing write permission'
+				);
+			} catch (NoReadAccessException $ex) {
+				// possible if the skeleton directory does not have read access
+				$this->logger->warning(
+					'Skeleton not created due to missing read permission in skeleton directory'
+				);
+			} catch(\OC\HintException $hintEx) {
+				// only if Skeleton no existing Dir
+				$this->logger->error($hintEx->getMessage());
+			}
+
+			// trigger any other initialization
+			\OC::$server->getEventDispatcher()->dispatch(IUser::class . '::firstLogin', new GenericEvent($this->getUser()));
+		}
 	}
 
 	/**
@@ -431,31 +487,33 @@ class Session implements IUserSession, Emitter {
 	 * @throws LoginException if an app canceld the login process or the user is not enabled
 	 */
 	private function loginWithPassword($uid, $password) {
-		$this->manager->emit('\OC\User', 'preLogin', array($uid, $password));
-		$user = $this->manager->checkPassword($uid, $password);
-		if ($user === false) {
-			// Password check failed
-			return false;
-		}
+		return $this->emittingCall(function () use (&$uid, &$password) {
+			$this->manager->emit('\OC\User', 'preLogin', [$uid, $password]);
+			$user = $this->manager->checkPassword($uid, $password);
+			if ($user === false) {
+				$this->manager->emit('\OC\User', 'failedLogin', [$uid]);
+				return false;
+			}
 
-		if ($user->isEnabled()) {
-			$this->setUser($user);
-			$this->setLoginName($uid);
-			$this->manager->emit('\OC\User', 'postLogin', array($user, $password));
-			if ($this->isLoggedIn()) {
-				$this->prepareUserLogin();
-				return true;
+			if ($user->isEnabled()) {
+				$this->setUser($user);
+				$this->setLoginName($uid);
+				$firstTimeLogin = $user->updateLastLoginTimestamp();
+				$this->manager->emit('\OC\User', 'postLogin', [$user, $password]);
+				if ($this->isLoggedIn()) {
+					$this->prepareUserLogin($firstTimeLogin);
+					return true;
+				} else {
+					// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
+					$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
+					throw new LoginException($message);
+				}
 			} else {
 				// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
-				$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
+				$message = \OC::$server->getL10N('lib')->t('User disabled');
 				throw new LoginException($message);
 			}
-		} else {
-			// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
-			$message = \OC::$server->getL10N('lib')->t('User disabled');
-			throw new LoginException($message);
-		}
-		return false;
+		}, ['before' => ['uid' => $uid, 'password' => $password], 'after' => ['uid' => $uid, 'password' => $password]], 'user', 'login');
 	}
 
 	/**
@@ -481,7 +539,7 @@ class Session implements IUserSession, Emitter {
 			// Ignore and use empty string instead
 		}
 
-		$this->manager->emit('\OC\User', 'preLogin', array($uid, $password));
+		$this->manager->emit('\OC\User', 'preLogin', [$uid, $password]);
 
 		$user = $this->manager->get($uid);
 		if (is_null($user)) {
@@ -498,7 +556,7 @@ class Session implements IUserSession, Emitter {
 		//login
 		$this->setUser($user);
 		$this->setLoginName($dbToken->getLoginName());
-		$this->manager->emit('\OC\User', 'postLogin', array($user, $password));
+		$this->manager->emit('\OC\User', 'postLogin', [$user, $password]);
 
 		if ($this->isLoggedIn()) {
 			$this->prepareUserLogin();
@@ -508,9 +566,97 @@ class Session implements IUserSession, Emitter {
 			throw new LoginException($message);
 		}
 
+		// set the app password
+		$this->session->set('app_password', $token);
+
 		return true;
 	}
 
+	/**
+	 * Try to login a user, assuming authentication
+	 * has already happened (e.g. via Single Sign On).
+	 *
+	 * Log in a user and regenerate a new session.
+	 *
+	 * @param \OCP\Authentication\IApacheBackend $apacheBackend
+	 * @return bool
+	 * @throws LoginException
+	 */
+	public function loginWithApache(IApacheBackend $apacheBackend) {
+
+		$uidAndBackend = $apacheBackend->getCurrentUserId();
+		if (is_array($uidAndBackend)
+			&& count($uidAndBackend) === 2
+			&& $uidAndBackend[0] !== ''
+			&& $uidAndBackend[0] !== null
+			&& $uidAndBackend[1] instanceof UserInterface
+		) {
+			list($uid, $backend) = $uidAndBackend;
+		} else if (is_string($uidAndBackend)) {
+			$uid = $uidAndBackend;
+			if ($apacheBackend instanceof UserInterface) {
+				$backend = $apacheBackend;
+			} else {
+				$this->logger->error('Apache backend failed to provide a valid backend for the user');
+				return false;
+			}
+		} else {
+			$this->logger->debug('No valid user detected from apache user backend');
+			return false;
+		}
+
+		if ($this->getUser() !== null && $uid === $this->getUser()->getUID()) {
+			return true; // nothing to do
+		}
+		$this->session->regenerateId();
+
+		$this->manager->emit('\OC\User', 'preLogin', [$uid, '']);
+
+		// Die here if not valid
+		if(!$apacheBackend->isSessionActive()) {
+			return false;
+		}
+
+		// Now we try to create the account or sync
+		$this->userSyncService->createOrSyncAccount($uid, $backend);
+
+		$user = $this->manager->get($uid);
+		if ($user === null) {
+			$this->manager->emit('\OC\User', 'failedLogin', [$uid]);
+			return false;
+		}
+
+		if ($user->isEnabled()) {
+			$this->setUser($user);
+			$this->setLoginName($uid);
+
+			$request = OC::$server->getRequest();
+			$this->createSessionToken($request, $uid, $uid);
+
+			// setup the filesystem
+			OC_Util::setupFS($uid);
+			// first call the post_login hooks, the login-process needs to be
+			// completed before we can safely create the users folder.
+			// For example encryption needs to initialize the users keys first
+			// before we can create the user folder with the skeleton files
+
+			$firstTimeLogin = $user->updateLastLoginTimestamp();
+			$this->manager->emit('\OC\User', 'postLogin', [$user, '']);
+			if ($this->isLoggedIn()) {
+				$this->prepareUserLogin($firstTimeLogin);
+				return true;
+			} else {
+				// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
+				$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
+				throw new LoginException($message);
+			}
+		} else {
+			// injecting l10n does not work - there is a circular dependency between session and \OCP\L10N\IFactory
+			$message = \OC::$server->getL10N('lib')->t('User disabled');
+			throw new LoginException($message);
+		}
+	}
+
 	/**
 	 * Create a new session token for the given user credentials
 	 *
@@ -570,10 +716,13 @@ class Session implements IUserSession, Emitter {
 	 */
 	private function checkTokenCredentials(IToken $dbToken, $token) {
 		// Check whether login credentials are still valid and the user was not disabled
-		// This check is performed each 5 minutes
+		// This check is performed each 5 minutes per default
+		// However, we try to read last_check_timeout from the appconfig table so the
+		// administrator could change this 5 minutes timeout
 		$lastCheck = $dbToken->getLastCheck() ? : 0;
-		$now = $this->timeFacory->getTime();
-		if ($lastCheck > ($now - 60 * 5)) {
+		$now = $this->timeFactory->getTime();
+		$last_check_timeout = intval($this->config->getAppValue('core', 'last_check_timeout', 5));
+		if ($lastCheck > ($now - 60 * $last_check_timeout)) {
 			// Checked performed recently, nothing to do now
 			return true;
 		}
@@ -624,8 +773,8 @@ class Session implements IUserSession, Emitter {
 		}
 
 		// Check if login names match
-		if (!is_null($user) && $dbToken->getLoginName() !== $user) {
-			// TODO: this makes it imposssible to use different login names on browser and client
+		if ($user !== null && $dbToken->getLoginName() !== $user) {
+			// TODO: this makes it impossible to use different login names on browser and client
 			// e.g. login by e-mail 'user@example.com' on browser for generating the token will not
 			//      allow to use the client token with the login name 'user'.
 			return false;
@@ -643,12 +792,13 @@ class Session implements IUserSession, Emitter {
 	/**
 	 * Tries to login the user with auth token header
 	 *
+	 * @param IRequest $request
 	 * @todo check remember me cookie
 	 * @return boolean
 	 */
 	public function tryTokenLogin(IRequest $request) {
 		$authHeader = $request->getHeader('Authorization');
-		if (strpos($authHeader, 'token ') === false) {
+		if ($authHeader === null || strpos($authHeader, 'token ') === false) {
 			// No auth header, let's try session id
 			try {
 				$token = $this->session->getId();
@@ -676,31 +826,16 @@ class Session implements IUserSession, Emitter {
 	 * @throws Exception If the auth module could not be loaded
 	 */
 	public function tryAuthModuleLogin(IRequest $request) {
-		/** @var IAppManager $appManager */
-		$appManager = OC::$server->query('AppManager');
-		$allApps = $appManager->getInstalledApps();
-		foreach ($allApps as $appId) {
-			$info = $appManager->getAppInfo($appId);
-			if (isset($info['auth-modules'])) {
-				$authModules = $info['auth-modules'];
-				foreach ($authModules as $class) {
-					try {
-						if (!OC_App::isAppLoaded($appId)) {
-							OC_App::loadApp($appId);
-						}
-						/** @var IAuthModule $authModule */
-						$authModule = OC::$server->query($class);
-						if ($authModule instanceof IAuthModule) {
-							return $this->loginUser($authModule->auth($request), $authModule->getUserPassword($request));
-						} else {
-							throw new Exception("Could not load the auth module $class");
-						}
-					} catch (QueryException $exc) {
-						throw new Exception("Could not load the auth module $class");
-					}
-				}
+		foreach ($this->getAuthModules(false) as $authModule) {
+			$user = $authModule->auth($request);
+			if ($user !== null) {
+				$uid = $user->getUID();
+				$password = $authModule->getUserPassword($request);
+				$this->createSessionToken($request, $uid, $uid, $password);
+				return $this->loginUser($user, $password);
 			}
 		}
+
 		return false;
 	}
 
@@ -712,25 +847,33 @@ class Session implements IUserSession, Emitter {
 	 * @return boolean True if the user can be authenticated, false otherwise
 	 * @throws LoginException if an app canceld the login process or the user is not enabled
 	 */
-	private function loginUser($user, $password) {
-		if (is_null($user)) {
-			return false;
-		}
-		$this->manager->emit('\OC\User', 'preLogin', [$user, $password]);
-		if (!$user->isEnabled()) {
-			$message = \OC::$server->getL10N('lib')->t('User disabled');
-			throw new LoginException($message);
-		}
-		$this->setUser($user);
-		$this->setLoginName($user->getDisplayName());
-		$this->manager->emit('\OC\User', 'postLogin', [$user, $password]);
-		if ($this->isLoggedIn()) {
-			$this->prepareUserLogin();
-		} else {
-			$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
-			throw new LoginException($message);
-		}
-		return true;
+	protected function loginUser($user, $password) {
+		return $this->emittingCall(function () use (&$user, &$password) {
+			if (is_null($user)) {
+				return false;
+			}
+
+			$this->manager->emit('\OC\User', 'preLogin', [$user, $password]);
+
+			if (!$user->isEnabled()) {
+				$message = \OC::$server->getL10N('lib')->t('User disabled');
+				throw new LoginException($message);
+			}
+
+			$this->setUser($user);
+			$this->setLoginName($user->getDisplayName());
+
+			$this->manager->emit('\OC\User', 'postLogin', [$user, $password]);
+
+			if ($this->isLoggedIn()) {
+				$this->prepareUserLogin(false);
+			} else {
+				$message = \OC::$server->getL10N('lib')->t('Login canceled by app');
+				throw new LoginException($message);
+			}
+
+			return true;
+		}, ['before' => ['uid' => $user, 'password' => $password], 'after' => ['uid' => $user, 'password' => $password]], 'user', 'login');
 	}
 
 	/**
@@ -742,7 +885,7 @@ class Session implements IUserSession, Emitter {
 	 */
 	public function loginWithCookie($uid, $currentToken) {
 		$this->session->regenerateId();
-		$this->manager->emit('\OC\User', 'preRememberedLogin', array($uid));
+		$this->manager->emit('\OC\User', 'preRememberedLogin', [$uid]);
 		$user = $this->manager->get($uid);
 		if (is_null($user)) {
 			// user does not exist
@@ -763,27 +906,44 @@ class Session implements IUserSession, Emitter {
 
 		//login
 		$this->setUser($user);
-		$this->manager->emit('\OC\User', 'postRememberedLogin', array($user));
+		$user->updateLastLoginTimestamp();
+		$this->manager->emit('\OC\User', 'postRememberedLogin', [$user]);
 		return true;
 	}
 
 	/**
 	 * logout the user from the session
+	 *
+	 * @return bool
 	 */
 	public function logout() {
-		$this->manager->emit('\OC\User', 'logout');
-		$user = $this->getUser();
-		if (!is_null($user)) {
-			try {
-				$this->tokenProvider->invalidateToken($this->session->getId());
-			} catch (SessionNotAvailableException $ex) {
-				
+		return $this->emittingCall(function () {
+			$event = new GenericEvent(null, ['cancel' => false]);
+			$eventDispatcher = \OC::$server->getEventDispatcher();
+			$eventDispatcher->dispatch('\OC\User\Session::pre_logout', $event);
+
+			$this->manager->emit('\OC\User', 'preLogout');
+
+			if ($event['cancel'] === true) {
+				return true;
 			}
-		}
-		$this->setUser(null);
-		$this->setLoginName(null);
-		$this->unsetMagicInCookie();
-		$this->session->clear();
+
+			$this->manager->emit('\OC\User', 'logout');
+			$user = $this->getUser();
+			if (!is_null($user)) {
+				try {
+					$this->tokenProvider->invalidateToken($this->session->getId());
+				} catch (SessionNotAvailableException $ex) {
+
+				}
+			}
+			$this->setUser(null);
+			$this->setLoginName(null);
+			$this->unsetMagicInCookie();
+			$this->session->clear();
+			$this->manager->emit('\OC\User', 'postLogout');
+			return true;
+		}, ['before' => ['uid' => ''], 'after' => ['uid' => '']], 'user', 'logout');
 	}
 
 	/**
@@ -837,4 +997,57 @@ class Session implements IUserSession, Emitter {
 		}
 	}
 
+	public function verifyAuthHeaders($request) {
+		$shallLogout = false;
+		try {
+			$lastUser = null;
+			foreach ($this->getAuthModules(true) as $module) {
+				$user = $module->auth($request);
+				if ($user !== null) {
+					if ($this->isLoggedIn() && $this->getUser()->getUID() !== $user->getUID()) {
+						$shallLogout = true;
+						break;
+					}
+					if ($lastUser !== null && $user->getUID() !== $lastUser->getUID()) {
+						$shallLogout = true;
+						break;
+					}
+					$lastUser = $user;
+				}
+			}
+
+		} catch (Exception $ex) {
+			$shallLogout = true;
+		}
+		if ($shallLogout) {
+			// the session is bad -> kill it
+			$this->logout();
+			return false;
+		}
+		return true;
+	}
+
+	/**
+	 * @param $includeBuiltIn
+	 * @return \Generator | IAuthModule[]
+	 * @throws Exception
+	 */
+	protected function getAuthModules($includeBuiltIn) {
+		if ($includeBuiltIn) {
+			yield new TokenAuthModule($this->session, $this->tokenProvider, $this->manager);
+		}
+
+		$modules = $this->serviceLoader->load(['auth-modules']);
+		foreach ($modules as $module) {
+			if ($module instanceof IAuthModule) {
+				yield $module;
+			} else {
+				continue;
+			}
+		}
+
+		if ($includeBuiltIn) {
+			yield new BasicAuthModule($this->config, $this->logger, $this->manager, $this->session, $this->timeFactory);
+		}
+	}
 }
