@@ -3,7 +3,6 @@
  * @author Arthur Schiwon <blizzz@arthur-schiwon.de>
  * @author Bart Visscher <bartv@thisnet.nl>
  * @author Bernhard Posselt <dev@bernhard-posselt.com>
- * @author Björn Schießle <bjoern@schiessle.org>
  * @author Borjan Tchakaloff <borjan@tchakaloff.fr>
  * @author Brice Maron <brice@bmaron.net>
  * @author Christopher Schäpers <kondou@ts.unde.re>
@@ -11,13 +10,14 @@
  * @author Frank Karlitschek <frank@karlitschek.de>
  * @author Georg Ehrke <georg@owncloud.com>
  * @author Jakob Sack <mail@jakobsack.de>
- * @author Jan-Christoph Borchardt <hey@jancborchardt.net>
- * @author Joas Schilling <nickvergessen@owncloud.com>
+ * @author Joas Schilling <coding@schilljs.com>
  * @author Jörn Friedrich Dreyer <jfd@butonic.de>
  * @author Kamil Domanski <kdomanski@kdemail.net>
  * @author Lukas Reschke <lukas@statuscode.ch>
  * @author Markus Goetz <markus@woboq.com>
  * @author Morris Jobke <hey@morrisjobke.de>
+ * @author Philipp Schaffrath <github@philippschaffrath.de>
+ * @author ppaysant <patrick.paysant@linagora.com>
  * @author RealRancor <Fisch.666@gmx.de>
  * @author Robin Appelman <icewind@owncloud.com>
  * @author Robin McCorkell <robin@mccorkell.me.uk>
@@ -28,7 +28,7 @@
  * @author Tom Needham <tom@owncloud.com>
  * @author Vincent Petry <pvince81@owncloud.com>
  *
- * @copyright Copyright (c) 2016, ownCloud, Inc.
+ * @copyright Copyright (c) 2018, ownCloud GmbH
  * @license AGPL-3.0
  *
  * This code is free software: you can redistribute it and/or modify
@@ -48,7 +48,6 @@ use OC\App\DependencyAnalyzer;
 use OC\App\InfoParser;
 use OC\App\Platform;
 use OC\Installer;
-use OC\OCSClient;
 use OC\Repair;
 
 /**
@@ -58,13 +57,15 @@ use OC\Repair;
  */
 class OC_App {
 	static private $appVersion = [];
-	static private $adminForms = array();
-	static private $personalForms = array();
-	static private $appInfo = array();
-	static private $appTypes = array();
-	static private $loadedApps = array();
-	static private $altLogin = array();
+	static private $adminForms = [];
+	static private $personalForms = [];
+	static private $appInfo = [];
+	static private $appTypes = [];
+	static private $loadedApps = [];
+	static private $loadedTypes = [];
+	static private $altLogin = [];
 	const officialApp = 200;
+	const approvedApp = 100;
 
 	/**
 	 * clean the appId
@@ -73,7 +74,7 @@ class OC_App {
 	 * @return string
 	 */
 	public static function cleanAppId($app) {
-		return str_replace(array('\0', '/', '\\', '..'), '', $app);
+		return str_replace(['\0', '/', '\\', '..'], '', $app);
 	}
 
 	/**
@@ -99,6 +100,9 @@ class OC_App {
 	 * if $types is set, only apps of those types will be loaded
 	 */
 	public static function loadApps($types = null) {
+		if (is_array($types) && !array_diff($types, self::$loadedTypes)) {
+			return true;
+		}
 		if (\OC::$server->getSystemConfig()->getValue('maintenance', false)) {
 			return false;
 		}
@@ -107,6 +111,9 @@ class OC_App {
 
 		// Add each apps' folder as allowed class path
 		foreach($apps as $app) {
+			if (self::isAppLoaded($app)) {
+				continue;
+			}
 			$path = self::getAppPath($app);
 			if($path !== false) {
 				self::registerAutoloading($app, $path);
@@ -122,6 +129,40 @@ class OC_App {
 		}
 		ob_end_clean();
 
+		// once all authentication apps are loaded we can validate the session
+		if (is_null($types) || in_array('authentication', $types)) {
+			if (\OC::$server->getUserSession()) {
+				$request = \OC::$server->getRequest();
+				$session = \OC::$server->getUserSession();
+				$davUser = \OC::$server->getUserSession()->getSession()->get(\OCA\DAV\Connector\Sabre\Auth::DAV_AUTHENTICATED);
+				if (is_null($davUser)) {
+					$session->validateSession();
+				} else {
+					/** @var \OC\Authentication\Token\DefaultTokenProvider $tokenProvider */
+					$tokenProvider = \OC::$server->query('\OC\Authentication\Token\DefaultTokenProvider');
+					$token = null;
+					try {
+						$token = $tokenProvider->getToken($session->getSession()->getId());
+					} catch (\Exception $ex) {
+						$password = null;
+						if (isset($_SERVER['PHP_AUTH_PW'])) {
+							$password = $_SERVER['PHP_AUTH_PW'];
+						}
+
+						$session->createSessionToken($request, $session->getUser()->getUID(), $session->getLoginName(), $password);
+					}
+
+					if ($token) {
+						$tokenProvider->updateToken($token);
+					}
+				}
+			}
+		}
+		if (is_array($types)) {
+			self::$loadedTypes = array_merge(self::$loadedTypes, $types);
+		}
+
+		\OC_Hook::emit('OC_App', 'loadedApps');
 		return true;
 	}
 
@@ -142,23 +183,37 @@ class OC_App {
 		// in case someone calls loadApp() directly
 		self::registerAutoloading($app, $appPath);
 
+		self::enableThemeIfApplicable($app);
+
 		if (is_file($appPath . '/appinfo/app.php')) {
 			\OC::$server->getEventLogger()->start('load_app_' . $app, 'Load app: ' . $app);
 			if ($checkUpgrade and self::shouldUpgrade($app)) {
 				throw new \OC\NeedsUpdateException();
 			}
 			self::requireAppFile($app);
-			if (self::isType($app, array('authentication'))) {
+			if (self::isType($app, ['authentication'])) {
 				// since authentication apps affect the "is app enabled for group" check,
 				// the enabled apps cache needs to be cleared to make sure that the
 				// next time getEnableApps() is called it will also include apps that were
 				// enabled for groups
-				self::$enabledAppsCache = array();
+				self::$enabledAppsCache = [];
 			}
 			\OC::$server->getEventLogger()->end('load_app_' . $app);
 		}
 	}
 
+	/**
+	 * Enables the app as a theme if it has the type "theme"
+	 * @param string $app
+	 */
+	private static function enableThemeIfApplicable($app) {
+		if (self::isType($app, 'theme')) {
+			/** @var \OCP\Theme\IThemeService $themeService */
+			$themeService = \OC::$server->query('ThemeService');
+			$themeService->setAppTheme($app);
+		}
+	}
+
 	/**
 	 * @internal
 	 * @param string $app
@@ -185,12 +240,18 @@ class OC_App {
 		try {
 			// encapsulated here to avoid variable scope conflicts
 			require_once $app . '/appinfo/app.php';
-		} catch (Error $ex) {
+		} catch (Exception $ex) {
 			\OC::$server->getLogger()->logException($ex);
 			$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
 			if (!in_array($app, $blacklist)) {
-				self::disable($app);
+				if (!self::isType($app, ['authentication', 'filesystem'])) {
+					\OC::$server->getLogger()->warning('Could not load app "' . $app . '", it will be disabled', array('app' => 'core'));
+					self::disable($app);
+				} else {
+					\OC::$server->getLogger()->warning('Could not load app "' . $app . '", see exception above', array('app' => 'core'));
+				}
 			}
+			throw $ex;
 		}
 	}
 
@@ -203,7 +264,7 @@ class OC_App {
 	 */
 	public static function isType($app, $types) {
 		if (is_string($types)) {
-			$types = array($types);
+			$types = [$types];
 		}
 		$appTypes = self::getAppTypes($app);
 		foreach ($types as $type) {
@@ -229,7 +290,7 @@ class OC_App {
 		if (isset(self::$appTypes[$app])) {
 			return explode(',', self::$appTypes[$app]);
 		} else {
-			return array();
+			return [];
 		}
 	}
 
@@ -266,7 +327,7 @@ class OC_App {
 	/**
 	 * get all enabled apps
 	 */
-	protected static $enabledAppsCache = array();
+	protected static $enabledAppsCache = [];
 
 	/**
 	 * Returns apps enabled for the current user.
@@ -278,7 +339,7 @@ class OC_App {
 	 */
 	public static function getEnabledApps($forceRefresh = false, $all = false) {
 		if (!\OC::$server->getSystemConfig()->getValue('installed', false)) {
-			return array();
+			return [];
 		}
 		// in incognito mode or when logged out, $user will be false,
 		// which is also the case during an upgrade
@@ -325,16 +386,20 @@ class OC_App {
 	 * This function set an app as enabled in appconfig.
 	 */
 	public static function enable($app, $groups = null) {
-		self::$enabledAppsCache = array(); // flush
-		if (!Installer::isInstalled($app)) {
-			$app = self::installApp($app);
-		} else {
-			// check for required dependencies
-			$config = \OC::$server->getConfig();
-			$l = \OC::$server->getL10N('core');
-			$info = self::getAppInfo($app);
+		self::$enabledAppsCache = []; // flush
 
-			self::checkAppDependencies($config, $l, $info);
+		// check for required dependencies
+		$config = \OC::$server->getConfig();
+		$l = \OC::$server->getL10N('core');
+		$info = self::getAppInfo($app);
+		if ($info === null) {
+			throw new \Exception("$app can't be enabled since it is not installed.");
+		}
+
+		self::checkAppDependencies($config, $l, $info);
+
+		if (!Installer::isInstalled($app)) {
+			Installer::installShippedApp($app);
 		}
 
 		$appManager = \OC::$server->getAppManager();
@@ -353,27 +418,6 @@ class OC_App {
 		}
 	}
 
-	/**
-	 * @param string $app
-	 * @return int
-	 */
-	private static function downloadApp($app) {
-		$ocsClient = new OCSClient(
-			\OC::$server->getHTTPClientService(),
-			\OC::$server->getConfig(),
-			\OC::$server->getLogger()
-		);
-		$appData = $ocsClient->getApplication($app, \OCP\Util::getVersion());
-		$download = $ocsClient->getApplicationDownload($app, \OCP\Util::getVersion());
-		if(isset($download['downloadlink']) and $download['downloadlink']!='') {
-			// Replace spaces in download link without encoding entire URL
-			$download['downloadlink'] = str_replace(' ', '%20', $download['downloadlink']);
-			$info = array('source' => 'http', 'href' => $download['downloadlink'], 'appdata' => $appData);
-			$app = Installer::installApp($info);
-		}
-		return $app;
-	}
-
 	/**
 	 * @param string $app
 	 * @return bool
@@ -399,7 +443,7 @@ class OC_App {
 		}
 
 		// flush
-		self::$enabledAppsCache = array();
+		self::$enabledAppsCache = [];
 
 		// run uninstall steps
 		$appData = OC_App::getAppInfo($app);
@@ -408,7 +452,7 @@ class OC_App {
 		}
 
 		// emit disable hook - needed anymore ?
-		\OC_Hook::emit('OC_App', 'pre_disable', array('app' => $app));
+		\OC_Hook::emit('OC_App', 'pre_disable', ['app' => $app]);
 
 		// finally disable it
 		$appManager = \OC::$server->getAppManager();
@@ -427,32 +471,32 @@ class OC_App {
 		$l = \OC::$server->getL10N('lib');
 		$urlGenerator = \OC::$server->getURLGenerator();
 
-		$settings = array();
+		$settings = [];
 		// by default, settings only contain the help menu
-		if (OC_Util::getEditionString() === '' &&
+		if (OC_Util::getEditionString() === OC_Util::EDITION_COMMUNITY &&
 			\OC::$server->getSystemConfig()->getValue('knowledgebaseenabled', true) == true
 		) {
-			$settings = array(
-				array(
+			$settings = [
+				[
 					"id" => "help",
 					"order" => 1000,
 					"href" => $urlGenerator->linkToRoute('settings_help'),
 					"name" => $l->t("Help"),
 					"icon" => $urlGenerator->imagePath("settings", "help.svg")
-				)
-			);
+				]
+			];
 		}
 
 		// if the user is logged-in
 		if (OC_User::isLoggedIn()) {
 			// personal menu
-			$settings[] = array(
-				"id" => "personal",
+			$settings[] = [
+				"id" => "settings",
 				"order" => 1,
-				"href" => $urlGenerator->linkToRoute('settings_personal'),
-				"name" => $l->t("Personal"),
-				"icon" => $urlGenerator->imagePath("settings", "personal.svg")
-			);
+				"href" => $urlGenerator->linkToRoute('settings.SettingsPage.getPersonal'),
+				"name" => $l->t("Settings"),
+				"icon" => $urlGenerator->imagePath("settings", "admin.svg")
+			];
 
 			//SubAdmins are also allowed to access user management
 			$userObject = \OC::$server->getUserSession()->getUser();
@@ -462,30 +506,18 @@ class OC_App {
 			}
 			if ($isSubAdmin) {
 				// admin users menu
-				$settings[] = array(
+				$settings[] = [
 					"id" => "core_users",
 					"order" => 2,
 					"href" => $urlGenerator->linkToRoute('settings_users'),
 					"name" => $l->t("Users"),
 					"icon" => $urlGenerator->imagePath("settings", "users.svg")
-				);
+				];
 			}
 
-			// if the user is an admin
-			if (OC_User::isAdminUser(OC_User::getUser())) {
-				// admin settings
-				$settings[] = array(
-					"id" => "admin",
-					"order" => 1000,
-					"href" => $urlGenerator->linkToRoute('settings_admin'),
-					"name" => $l->t("Admin"),
-					"icon" => $urlGenerator->imagePath("settings", "admin.svg")
-				);
-			}
 		}
 
-		$navigation = self::proceedNavigation($settings);
-		return $navigation;
+		return self::proceedNavigation($settings);
 	}
 
 	// This is private as well. It simply works, so don't ask for more details
@@ -500,7 +532,17 @@ class OC_App {
 		}
 		unset($navEntry);
 
-		usort($list, create_function('$a, $b', 'if( $a["order"] == $b["order"] ) {return 0;}elseif( $a["order"] < $b["order"] ) {return -1;}else{return 1;}'));
+		usort($list, function($a, $b) {
+			if ($a["order"] == $b["order"]) {
+				return 0;
+			}
+
+			if($a["order"] < $b["order"]) {
+				return -1;
+			}
+
+			return 1;
+		});
 
 		return $list;
 	}
@@ -508,13 +550,9 @@ class OC_App {
 	/**
 	 * Get the path where to install apps
 	 *
-	 * @return string|false
+	 * @return string|null
 	 */
 	public static function getInstallPath() {
-		if (\OC::$server->getSystemConfig()->getValue('appstoreenabled', true) == false) {
-			return false;
-		}
-
 		foreach (OC::$APPSROOTS as $dir) {
 			if (isset($dir['writable']) && $dir['writable'] === true) {
 				return $dir['path'];
@@ -525,72 +563,29 @@ class OC_App {
 		return null;
 	}
 
-
-	/**
-	 * search for an app in all app-directories
-	 *
-	 * @param string $appId
-	 * @return false|string
-	 */
-	protected static function findAppInDirectories($appId) {
-		$sanitizedAppId = self::cleanAppId($appId);
-		if($sanitizedAppId !== $appId) {
-			return false;
-		}
-		static $app_dir = array();
-
-		if (isset($app_dir[$appId])) {
-			return $app_dir[$appId];
-		}
-
-		$possibleApps = array();
-		foreach (OC::$APPSROOTS as $dir) {
-			if (file_exists($dir['path'] . '/' . $appId)) {
-				$possibleApps[] = $dir;
-			}
-		}
-
-		if (empty($possibleApps)) {
-			return false;
-		} elseif (count($possibleApps) === 1) {
-			$dir = array_shift($possibleApps);
-			$app_dir[$appId] = $dir;
-			return $dir;
-		} else {
-			$versionToLoad = array();
-			foreach ($possibleApps as $possibleApp) {
-				$version = self::getAppVersionByPath($possibleApp['path'] . '/' . $appId);
-				if (empty($versionToLoad) || version_compare($version, $versionToLoad['version'], '>')) {
-					$versionToLoad = array(
-						'dir' => $possibleApp,
-						'version' => $version,
-					);
-				}
-			}
-			$app_dir[$appId] = $versionToLoad['dir'];
-			return $versionToLoad['dir'];
-			//TODO - write test
-		}
-	}
-
 	/**
 	 * Get the directory for the given app.
-	 * If the app is defined in multiple directories, the first one is taken. (false if not found)
+	 * If the app exists in multiple directories, the most recent version is taken.
+	 * (false if not found)
 	 *
 	 * @param string $appId
 	 * @return string|false
 	 */
 	public static function getAppPath($appId) {
-		if ($appId === null || trim($appId) === '') {
-			return false;
-		}
-
-		if (($dir = self::findAppInDirectories($appId)) != false) {
-			return $dir['path'] . '/' . $appId;
-		}
-		return false;
+		return \OC::$server->getAppManager()->getAppPath($appId);
 	}
 
+	/**
+	 * Get the web path for the given app.
+	 * If the app exists in multiple directories, the most recent version is taken.
+	 * (false if not found)
+	 *
+	 * @param string $appId
+	 * @return string|false
+	 */
+	public static function getAppWebPath($appId) {
+		return \OC::$server->getAppManager()->getAppWebPath($appId);
+	}
 
 	/**
 	 * check if an app's directory is writable
@@ -603,20 +598,6 @@ class OC_App {
 		return ($path !== false) ? is_writable($path) : false;
 	}
 
-	/**
-	 * Get the path for the given app on the access
-	 * If the app is defined in multiple directories, the first one is taken. (false if not found)
-	 *
-	 * @param string $appId
-	 * @return string|false
-	 */
-	public static function getAppWebPath($appId) {
-		if (($dir = self::findAppInDirectories($appId)) != false) {
-			return OC::$WEBROOT . $dir['url'] . '/' . $appId;
-		}
-		return false;
-	}
-
 	/**
 	 * get the last version of the app from appinfo/info.xml
 	 *
@@ -643,7 +624,6 @@ class OC_App {
 		return isset($appData['version']) ? $appData['version'] : '';
 	}
 
-
 	/**
 	 * Read all app metadata from the info.xml file
 	 *
@@ -696,8 +676,7 @@ class OC_App {
 	 */
 	public static function getNavigation() {
 		$entries = OC::$server->getNavigationManager()->getAll();
-		$navigation = self::proceedNavigation($entries);
-		return $navigation;
+		return self::proceedNavigation($entries);
 	}
 
 	/**
@@ -728,7 +707,7 @@ class OC_App {
 	 * @return array
 	 */
 	public static function getForms($type) {
-		$forms = array();
+		$forms = [];
 		switch ($type) {
 			case 'admin':
 				$source = self::$adminForms;
@@ -737,10 +716,14 @@ class OC_App {
 				$source = self::$personalForms;
 				break;
 			default:
-				return array();
+				return [];
 		}
 		foreach ($source as $form) {
-			$forms[] = include $form;
+			$page = include $form['page'];
+			$forms[] = [
+				'appId' => $form['appId'],
+				'page' => $page,
+			];
 		}
 		return $forms;
 	}
@@ -750,18 +733,26 @@ class OC_App {
 	 *
 	 * @param string $app
 	 * @param string $page
+	 * @deprecated Register settings panels in info.xml
 	 */
 	public static function registerAdmin($app, $page) {
-		self::$adminForms[] = $app . '/' . $page . '.php';
+		self::$adminForms[] = [
+			'appId' => $app,
+			'page' => $app . '/' . $page . '.php',
+		];
 	}
 
 	/**
 	 * register a personal form to be shown
 	 * @param string $app
 	 * @param string $page
+	 * @deprecated Register settings panels in info.xml
 	 */
 	public static function registerPersonal($app, $page) {
-		self::$personalForms[] = $app . '/' . $page . '.php';
+		self::$personalForms[] = [
+			'appId' => $app,
+			'page' => $app . '/' . $page . '.php',
+		];
 	}
 
 	/**
@@ -786,7 +777,7 @@ class OC_App {
 	 */
 	public static function getAllApps() {
 
-		$apps = array();
+		$apps = [];
 
 		foreach (OC::$APPSROOTS as $apps_dir) {
 			if (!is_readable($apps_dir['path'])) {
@@ -815,12 +806,9 @@ class OC_App {
 	 * @param bool $onlyLocal
 	 * @param bool $includeUpdateInfo Should we check whether there is an update
 	 *                                in the app store?
-	 * @param OCSClient $ocsClient
 	 * @return array
 	 */
-	public static function listAllApps($onlyLocal = false,
-									   $includeUpdateInfo = true,
-									   OCSClient $ocsClient) {
+	public static function listAllApps() {
 		$installedApps = OC_App::getAllApps();
 
 		//TODO which apps do we want to blacklist and how do we integrate
@@ -828,7 +816,7 @@ class OC_App {
 
 		//we don't want to show configuration for these
 		$blacklist = \OC::$server->getAppManager()->getAlwaysEnabledApps();
-		$appList = array();
+		$appList = [];
 		$urlGenerator = \OC::$server->getURLGenerator();
 
 		foreach ($installedApps as $app) {
@@ -863,12 +851,17 @@ class OC_App {
 					$info['level'] = self::officialApp;
 					$info['removable'] = false;
 				} else {
+					$result = \OC::$server->getIntegrityCodeChecker()->verifyAppSignature($app, '', true);
+					if (empty($result)) {
+						$info['internal'] = false;
+						$info['level'] = self::approvedApp;
+						$info['removable'] = false;
+					}
+
 					$info['internal'] = false;
 					$info['removable'] = true;
 				}
 
-				$info['update'] = ($includeUpdateInfo) ? Installer::isUpdateAvailable($app) : null;
-
 				$appPath = self::getAppPath($app);
 				if($appPath !== false) {
 					$appIcon = $appPath . '/img/' . $app . '.svg';
@@ -900,29 +893,8 @@ class OC_App {
 				$appList[] = $info;
 			}
 		}
-		if ($onlyLocal) {
-			$remoteApps = [];
-		} else {
-			$remoteApps = OC_App::getAppstoreApps('approved', null, $ocsClient);
-		}
-		if ($remoteApps) {
-			// Remove duplicates
-			foreach ($appList as $app) {
-				foreach ($remoteApps AS $key => $remote) {
-					if ($app['name'] === $remote['name'] ||
-						(isset($app['ocsid']) &&
-							$app['ocsid'] === $remote['id'])
-					) {
-						unset($remoteApps[$key]);
-					}
-				}
-			}
-			$combinedApps = array_merge($appList, $remoteApps);
-		} else {
-			$combinedApps = $appList;
-		}
 
-		return $combinedApps;
+		return $appList;
 	}
 
 	/**
@@ -940,76 +912,12 @@ class OC_App {
 		return false;
 	}
 
-	/**
-	 * Get a list of all apps on the appstore
-	 * @param string $filter
-	 * @param string|null $category
-	 * @param OCSClient $ocsClient
-	 * @return array|bool  multi-dimensional array of apps.
-	 *                     Keys: id, name, type, typename, personid, license, detailpage, preview, changed, description
-	 */
-	public static function getAppstoreApps($filter = 'approved',
-										   $category = null,
-										   OCSClient $ocsClient) {
-		$categories = [$category];
-
-		if (is_null($category)) {
-			$categoryNames = $ocsClient->getCategories(\OCP\Util::getVersion());
-			if (is_array($categoryNames)) {
-				// Check that categories of apps were retrieved correctly
-				if (!$categories = array_keys($categoryNames)) {
-					return false;
-				}
-			} else {
-				return false;
-			}
-		}
-
-		$page = 0;
-		$remoteApps = $ocsClient->getApplications($categories, $page, $filter, \OCP\Util::getVersion());
-		$apps = [];
-		$i = 0;
-		$l = \OC::$server->getL10N('core');
-		foreach ($remoteApps as $app) {
-			$potentialCleanId = self::getInternalAppIdByOcs($app['id']);
-			// enhance app info (for example the description)
-			$apps[$i] = OC_App::parseAppInfo($app);
-			$apps[$i]['author'] = $app['personid'];
-			$apps[$i]['ocs_id'] = $app['id'];
-			$apps[$i]['internal'] = 0;
-			$apps[$i]['active'] = ($potentialCleanId !== false) ? self::isEnabled($potentialCleanId) : false;
-			$apps[$i]['update'] = false;
-			$apps[$i]['groups'] = false;
-			$apps[$i]['score'] = $app['score'];
-			$apps[$i]['removable'] = false;
-			if ($app['label'] == 'recommended') {
-				$apps[$i]['internallabel'] = (string)$l->t('Recommended');
-				$apps[$i]['internalclass'] = 'recommendedapp';
-			}
-
-			// Apps from the appstore are always assumed to be compatible with the
-			// the current release as the initial filtering is done on the appstore
-			$apps[$i]['dependencies']['owncloud']['@attributes']['min-version'] = implode('.', \OCP\Util::getVersion());
-			$apps[$i]['dependencies']['owncloud']['@attributes']['max-version'] = implode('.', \OCP\Util::getVersion());
-
-			$i++;
-		}
-
-
-
-		if (empty($apps)) {
-			return false;
-		} else {
-			return $apps;
-		}
-	}
-
 	public static function shouldUpgrade($app) {
 		$versions = self::getAppVersions();
 		$currentVersion = OC_App::getAppVersion($app);
 		if ($currentVersion && isset($versions[$app])) {
 			$installedVersion = $versions[$app];
-			if (version_compare($currentVersion, $installedVersion, '>')) {
+			if (!version_compare($currentVersion, $installedVersion, '=')) {
 				return true;
 			}
 		}
@@ -1049,7 +957,7 @@ class OC_App {
 	 * This means that it's possible to specify "requiremin" => 6
 	 * and "requiremax" => 6 and it will still match ownCloud 6.0.3.
 	 *
-	 * @param string $ocVersion ownCloud version to check against
+	 * @param string|array $ocVersion ownCloud version to check against
 	 * @param array $appInfo app info (from xml)
 	 *
 	 * @return boolean true if compatible, otherwise false
@@ -1104,82 +1012,6 @@ class OC_App {
 		return $versions;
 	}
 
-	/**
-	 * @param string $app
-	 * @return bool
-	 * @throws Exception if app is not compatible with this version of ownCloud
-	 * @throws Exception if no app-name was specified
-	 */
-	public static function installApp($app) {
-		$l = \OC::$server->getL10N('core');
-		$config = \OC::$server->getConfig();
-		$ocsClient = new OCSClient(
-			\OC::$server->getHTTPClientService(),
-			$config,
-			\OC::$server->getLogger()
-		);
-		$appData = $ocsClient->getApplication($app, \OCP\Util::getVersion());
-
-		// check if app is a shipped app or not. OCS apps have an integer as id, shipped apps use a string
-		if (!is_numeric($app)) {
-			$shippedVersion = self::getAppVersion($app);
-			if ($appData && version_compare($shippedVersion, $appData['version'], '<')) {
-				$app = self::downloadApp($app);
-			} else {
-				$app = Installer::installShippedApp($app);
-			}
-		} else {
-			// Maybe the app is already installed - compare the version in this
-			// case and use the local already installed one.
-			// FIXME: This is a horrible hack. I feel sad. The god of code cleanness may forgive me.
-			$internalAppId = self::getInternalAppIdByOcs($app);
-			if($internalAppId !== false) {
-				if($appData && version_compare(\OC_App::getAppVersion($internalAppId), $appData['version'], '<')) {
-					$app = self::downloadApp($app);
-				} else {
-					self::enable($internalAppId);
-					$app = $internalAppId;
-				}
-			} else {
-				$app = self::downloadApp($app);
-			}
-		}
-
-		if ($app !== false) {
-			// check if the app is compatible with this version of ownCloud
-			$info = self::getAppInfo($app);
-			if(!is_array($info)) {
-				throw new \Exception(
-					$l->t('App "%s" cannot be installed because appinfo file cannot be read.',
-						[$info['name']]
-					)
-				);
-			}
-
-			$version = \OCP\Util::getVersion();
-			if (!self::isAppCompatible($version, $info)) {
-				throw new \Exception(
-					$l->t('App "%s" cannot be installed because it is not compatible with this version of ownCloud.',
-						array($info['name'])
-					)
-				);
-			}
-
-			// check for required dependencies
-			self::checkAppDependencies($config, $l, $info);
-
-			$config->setAppValue($app, 'enabled', 'yes');
-			if (isset($appData['id'])) {
-				$config->setAppValue($app, 'ocsid', $appData['id']);
-			}
-			\OC_Hook::emit('OC_App', 'post_enable', array('app' => $app));
-		} else {
-			throw new \Exception($l->t("No app name specified"));
-		}
-
-		return $app;
-	}
-
 	/**
 	 * update the database for the app and call the update script
 	 *
@@ -1193,12 +1025,17 @@ class OC_App {
 		}
 		$appData = self::getAppInfo($appId);
 		self::executeRepairSteps($appId, $appData['repair-steps']['pre-migration']);
-		if (file_exists($appPath . '/appinfo/database.xml')) {
-			OC_DB::updateDbFromStructure($appPath . '/appinfo/database.xml');
+		if (isset($appData['use-migrations']) && $appData['use-migrations'] === 'true') {
+			$ms = new \OC\DB\MigrationService($appId, \OC::$server->getDatabaseConnection());
+			$ms->migrate();
+		} else {
+			if (file_exists($appPath . '/appinfo/database.xml')) {
+				OC_DB::updateDbFromStructure($appPath . '/appinfo/database.xml');
+			}
 		}
 		self::executeRepairSteps($appId, $appData['repair-steps']['post-migration']);
 		self::setupLiveMigrations($appId, $appData['repair-steps']['live-migration']);
-		unset(self::$appVersion[$appId]);
+		self::clearAppCache($appId);
 		// run upgrade code
 		if (file_exists($appPath . '/appinfo/update.php')) {
 			self::loadApp($appId, false);
@@ -1335,9 +1172,9 @@ class OC_App {
 	}
 
 	/**
-	 * @param $config
-	 * @param $l
-	 * @param $info
+	 * @param OCP\IConfig $config
+	 * @param OCP\IL10N $l
+	 * @param array $info
 	 * @throws Exception
 	 */
 	protected static function checkAppDependencies($config, $l, $info) {
@@ -1352,4 +1189,12 @@ class OC_App {
 			);
 		}
 	}
+
+	/**
+	 * @param $appId
+	 */
+	public static function clearAppCache($appId) {
+		unset(self::$appVersion[$appId]);
+		unset(self::$appInfo[$appId]);
+	}
 }
